"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _Accordion = _interopRequireDefault(require("./Accordion"));

var _AccordionDetails = _interopRequireDefault(require("./AccordionDetails"));

var _AccordionSummary = _interopRequireDefault(require("./AccordionSummary"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Accordion>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Accordion["default"], null, /*#__PURE__*/_react["default"].createElement(_AccordionDetails["default"], null)));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Accordion["default"], null, /*#__PURE__*/_react["default"].createElement(_AccordionSummary["default"], null), /*#__PURE__*/_react["default"].createElement(_AccordionDetails["default"], null)));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Accordion["default"], null, /*#__PURE__*/_react["default"].createElement(_AccordionDetails["default"], null)));
      expect(wrapper.find("Accordion").props().classes).toEqual([]);
      expect(wrapper.find("Accordion").props().defaultExpanded).toEqual(false);
      expect(wrapper.find("Accordion").props().disabled).toEqual(false);
    });
  });
  describe("children prop", function () {
    it("renders given children", function () {
      var child = /*#__PURE__*/_react["default"].createElement(_AccordionDetails["default"], null, "hello");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Accordion["default"], null, child));
      expect(wrapper.find("Accordion").contains(child)).toEqual(true);
    });
  });
  describe("classes prop", function () {
    it("applies custom classes", function () {
      var classes = ["classOne"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Accordion["default"], {
        classes: classes
      }, /*#__PURE__*/_react["default"].createElement(_AccordionDetails["default"], null, "hello")));
      expect(wrapper.find("Accordion").childAt(0).hasClass(classes[0])).toEqual(true);
    });
  });
  describe("defaultExpanded prop", function () {
    it("applies explanded class to root given defaultExpanded is true", function () {
      var defaultExpanded = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Accordion["default"], {
        defaultExpanded: defaultExpanded
      }, /*#__PURE__*/_react["default"].createElement(_AccordionDetails["default"], null, "hello")));
      expect(wrapper.find("Accordion").childAt(0).hasClass("expanded")).toEqual(true);
    });
    it("does not apply explanded class to root given defaultExpanded is false", function () {
      var defaultExpanded = false;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Accordion["default"], {
        defaultExpanded: defaultExpanded
      }, /*#__PURE__*/_react["default"].createElement(_AccordionDetails["default"], null, "hello")));
      expect(wrapper.find("Accordion").childAt(0).hasClass("expanded")).toEqual(false);
    });
    it("sets expanded class with given defaultExpanded", function () {
      var defaultExpanded = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Accordion["default"], {
        defaultExpanded: defaultExpanded
      }, /*#__PURE__*/_react["default"].createElement(_AccordionDetails["default"], null, "hello")));
      expect(wrapper.find("Collapse").props()["in"]).toEqual(defaultExpanded);
    });
  });
  describe("expanded state", function () {
    it("sets correct expanded class to root when summary is clicked", function () {
      var defaultExpanded = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Accordion["default"], {
        defaultExpanded: defaultExpanded
      }, /*#__PURE__*/_react["default"].createElement(_AccordionSummary["default"], {
        id: "test-summary"
      }, "summary"), /*#__PURE__*/_react["default"].createElement(_AccordionDetails["default"], null, "hello")));
      wrapper.find("#test-summary").at(1).invoke("onClick")();
      expect(wrapper.find("Accordion").childAt(0).hasClass("expanded")).toEqual(false);
    });
    it("sets correct expanded class to Collaspe element when summary is clicked", function () {
      var defaultExpanded = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Accordion["default"], {
        defaultExpanded: defaultExpanded
      }, /*#__PURE__*/_react["default"].createElement(_AccordionSummary["default"], {
        id: "test-summary"
      }, "summary"), /*#__PURE__*/_react["default"].createElement(_AccordionDetails["default"], null, "hello")));
      wrapper.find("#test-summary").at(1).invoke("onClick")();
      expect(wrapper.find("Collapse").props()["in"]).toEqual(!defaultExpanded);
    });
  });
  describe("disabled prop", function () {
    it("applies disabled class name when disabled is true", function () {
      var disabled = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Accordion["default"], {
        disabled: disabled
      }, /*#__PURE__*/_react["default"].createElement(_AccordionDetails["default"], null, "hello")));
      expect(wrapper.find("Accordion").childAt(0).hasClass("disabled")).toEqual(true);
    });
    it("applies disabled class name when disabled is false", function () {
      var disabled = false;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Accordion["default"], {
        disabled: disabled
      }, /*#__PURE__*/_react["default"].createElement(_AccordionDetails["default"], null, "hello")));
      expect(wrapper.find("Accordion").childAt(0).hasClass("disabled")).toEqual(false);
    });
  });
});