"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _AppBar = _interopRequireDefault(require("./AppBar"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<AppBar>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_AppBar["default"], null));
    } catch (theError) {
      error = theError;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_AppBar["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  it("sets correct default props", function () {
    var defaultProps = new _AppBar["default"]().type.defaultProps;
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_AppBar["default"], null));
    expect(wrapper.find("AppBar").props().color).toEqual(defaultProps.color);
    expect(wrapper.find("AppBar").props().position).toEqual(defaultProps.position);
  });
  describe("children prop", function () {
    it("displays given children", function () {
      var child = /*#__PURE__*/_react["default"].createElement("div", null, "A child");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_AppBar["default"], null, child));
      expect(wrapper.containsMatchingElement(child)).toBeTruthy();
    });
  });
  describe("classes prop", function () {
    it("sets custom class", function () {
      var classVariant = ["newClass"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_AppBar["default"], {
        classes: classVariant
      }));
      expect(wrapper.find("AppBar").childAt(0).hasClass(classVariant[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClasses decorator", function () {
      var classes = ["riipen", "riipen-appbar"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_AppBar["default"], null));
      expect(wrapper.find("AppBar").props().classes.sort()).toEqual(classes.sort());
    });
  });
  describe("color prop", function () {
    it("sets color class name with valid custom colour", function () {
      var colorVariant = "secondary";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_AppBar["default"], {
        color: colorVariant
      }));
      expect(wrapper.find("AppBar").props().color).toEqual(colorVariant);
      expect(wrapper.find("AppBar").childAt(0).hasClass(colorVariant)).toEqual(true);
    });
    it("throws an error with invalid color", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_AppBar["default"], {
        color: "orange"
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("position prop", function () {
    it("sets position class name with valid custom position", function () {
      var positionVariant = "absolute";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_AppBar["default"], {
        position: positionVariant
      }));
      expect(wrapper.find("AppBar").props().position).toEqual(positionVariant);
      expect(wrapper.find("AppBar").childAt(0).hasClass(positionVariant)).toEqual(true);
    });
    it("throws an error with invalid position", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_AppBar["default"], {
        position: "upright"
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
});