"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _Avatar = _interopRequireDefault(require("./Avatar"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Avatar>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Avatar["default"], null));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Avatar["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var defaultProps = new _Avatar["default"]().type.defaultProps;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Avatar["default"], null));
      expect(wrapper.find("Avatar").props().size).toEqual(defaultProps.size);
      expect(wrapper.find("Avatar").props().variant).toEqual(defaultProps.variant);
    });
  });
  describe("alt prop", function () {
    it("renders an img tag with alt value", function () {
      var altVariant = "Test String";
      var srcVariant = "/static/images/avatars/jordan-ell.png";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Avatar["default"], {
        alt: altVariant,
        src: srcVariant
      }));
      expect(wrapper.find("img").props().alt).toEqual(altVariant);
    });
  });
  describe("children prop", function () {
    it("displays given children", function () {
      var child = /*#__PURE__*/_react["default"].createElement("div", null, "ZZ");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Avatar["default"], null, child));
      expect(wrapper.find(".inner").children().contains(child)).toEqual(true);
    });
  });
  describe("classes prop", function () {
    it("sets custom class", function () {
      var classVariant = ["newClass"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Avatar["default"], {
        classes: classVariant
      }));
      expect(wrapper.find("Avatar").childAt(0).hasClass(classVariant[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClass decorator", function () {
      var classes = ["riipen", "riipen-avatar"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Avatar["default"], null));
      expect(wrapper.find("Avatar").props().classes).toEqual(classes.sort());
    });
  });
  describe("size prop", function () {
    it("sets correct border size when size is above 70", function () {
      var sizeVariant = "75px";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Avatar["default"], {
        size: sizeVariant
      }));
      expect(wrapper.find("Avatar").instance().getBorderSize()).toEqual("4px");
    });
    it("sets correct border size when size is below 70", function () {
      var sizeVariant = "65px";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Avatar["default"], {
        size: sizeVariant
      }));
      expect(wrapper.find("Avatar").instance().getBorderSize()).toEqual("2px");
    });
  });
  describe("src prop", function () {
    it("renders an img tag with src value", function () {
      var srcVariant = "/static/images/avatars/jordan-ell.png";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Avatar["default"], {
        src: srcVariant
      }));
      expect(wrapper.find("Avatar").find("img")).toHaveLength(1);
      expect(wrapper.find("img").props().src).toEqual(srcVariant);
    });
  });
  describe("variant prop", function () {
    it("sets variant class name with valid custom variant", function () {
      var variant = "rounded";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Avatar["default"], {
        variant: variant
      }));
      expect(wrapper.find("Avatar").childAt(0).hasClass(variant)).toEqual(true);
    });
    it("throws an error with with invalid variant", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Avatar["default"], {
        variant: "star"
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
});