"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _Badge = _interopRequireDefault(require("./Badge"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Badge>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], null));
    } catch (theError) {
      error = theError;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var defaultProps = new _Badge["default"]().type.defaultProps;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], null));
      expect(wrapper.find("Badge").props().anchor.horizontal).toEqual(defaultProps.anchor.horizontal);
      expect(wrapper.find("Badge").props().anchor.vertical).toEqual(defaultProps.anchor.vertical);
      expect(wrapper.find("Badge").props().color).toEqual(defaultProps.color);
      expect(wrapper.find("Badge").props().component).toEqual(defaultProps.component);
      expect(wrapper.find("Badge").props().max).toEqual(defaultProps.max);
      expect(wrapper.find("Badge").props().overlap).toEqual(defaultProps.overlap);
      expect(wrapper.find("Badge").props().showZero).toEqual(defaultProps.showZero);
      expect(wrapper.find("Badge").props().size).toEqual(defaultProps.size);
      expect(wrapper.find("Badge").props().variant).toEqual(defaultProps.variant);
    });
  });
  describe("anchor prop", function () {
    it("sets anchor class name with valid custom anchor", function () {
      var anchor = {
        horizontal: "left",
        vertical: "bottom"
      };
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], {
        anchor: anchor
      }));
      expect(wrapper.find("Badge").childAt(0).childAt(0).hasClass("bottom-left-rectangle")).toEqual(true);
    });
    it("gives an error when given an invalid anchor", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var anchor = {
        horizontal: "side",
        vertical: "up"
      };
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], {
        anchor: anchor
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("children prop", function () {
    it("displays given children", function () {
      var child = /*#__PURE__*/_react["default"].createElement("div", null, "child");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], null, child));
      expect(wrapper.containsMatchingElement(child)).toBeTruthy();
    });
  });
  describe("classes prop", function () {
    it("sets custom class", function () {
      var classVariant = ["newClass"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], {
        classes: classVariant
      }));
      expect(wrapper.find("Badge").childAt(0).childAt(0).hasClass(classVariant[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClasses decorator", function () {
      var classes = ["riipen", "riipen-badge"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], null));
      expect(wrapper.find("Badge").props().classes.sort()).toEqual(classes.sort());
    });
  });
  describe("color prop", function () {
    it("sets color class name with a valid color", function () {
      var color = "muted";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], {
        color: color
      }));
      expect(wrapper.find("Badge").childAt(0).childAt(0).hasClass(color)).toEqual(true);
    });
    it("gives an error when given an invalid color", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], {
        color: "blue"
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("component prop", function () {
    it("sets component with valid custom component", function () {
      var component = "a";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], {
        component: component
      }));
      expect(wrapper.find(component)).toHaveLength(1);
      expect(wrapper.find("Badge").childAt(0).name()).toEqual(component);
    });
    it("gives an error when given an invalid component", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var component = "abcdefg";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], {
        component: component
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("content prop", function () {
    it("hides badge when content is 0 and showZero is false", function () {
      var content = 0;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], {
        content: content
      }));
      expect(wrapper.find("Badge").childAt(0).childAt(0).hasClass("hidden")).toEqual(true);
    });
    it("renders badge when content is 0 and showZero is true", function () {
      var content = 0;
      var showZero = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], {
        content: content,
        showZero: showZero
      }));
      expect(Number(wrapper.find("Badge").text())).toEqual(content);
    });
    it("renders badge when content is greater than 0 and showZero is true", function () {
      var content = 1;
      var showZero = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], {
        content: content,
        showZero: showZero
      }));
      expect(Number(wrapper.find("Badge").text())).toEqual(content);
    });
  });
  describe("max prop", function () {
    it("displays max value given content greater than max value", function () {
      var max = 9;
      var content = 11;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], {
        max: max,
        content: content
      }));
      expect(wrapper.text()).toEqual("".concat(max, "+"));
    });
    it("displays content value given content less than max value", function () {
      var max = 9;
      var content = 8;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], {
        max: max,
        content: content
      }));
      expect(Number(wrapper.text())).toEqual(content);
    });
  });
  describe("overlap prop", function () {
    it("sets overlap class name with valid custom overlap", function () {
      var anchor = {
        horizontal: "left",
        vertical: "top"
      };
      var overlap = "circle";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], {
        anchor: anchor,
        overlap: overlap
      }));
      expect(wrapper.find("Badge").childAt(0).childAt(0).hasClass("top-left-circle")).toEqual(true);
    });
    it("gives an error when given an invalid overlap", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], {
        overlap: "square"
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("showZero prop", function () {
    it("badge renders when showZero prop value is true", function () {
      var showZero = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], {
        showZero: showZero
      }));
      expect(wrapper.find("Badge").childAt(0).childAt(0).hasClass("hidden")).toEqual(false);
    });
  });
  describe("size prop", function () {
    it("sets size class name with a valid size", function () {
      var size = "small";
      var variant = "standard";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], {
        size: size,
        variant: variant
      }));
      expect(wrapper.find("Badge").childAt(0).childAt(0).hasClass(size)).toEqual(true);
    });
    it("does not set size class name when non standard variant prop used", function () {
      var size = "small";
      var variant = "dot";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], {
        size: size,
        variant: variant
      }));
      expect(wrapper.find("Badge").childAt(0).childAt(0).hasClass(size)).toEqual(false);
    });
    it("gives an error when given an invalid size", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var size = "large";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], {
        size: size
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("variant prop", function () {
    it("sets variant class name with valid custom variant", function () {
      var variant = "dot";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], {
        variant: variant
      }));
      expect(wrapper.find("Badge").childAt(0).childAt(0).hasClass(variant)).toEqual(true);
    });
    it("throws an error with with invalid variant", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Badge["default"], {
        variant: "circle"
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
});