"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _Banner = _interopRequireDefault(require("./Banner.jsx"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Banner>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Banner["default"], null));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Banner["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("children prop", function () {
    it("renders given children", function () {
      var child = /*#__PURE__*/_react["default"].createElement("h5", null, "hi hi");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Banner["default"], null, child));
      expect(wrapper.find("Banner").childAt(0).contains(child)).toEqual(true);
    });
  });
  describe("classes prop", function () {
    it("applies all classes to the div inside of Banner", function () {
      var classes = ["classOne"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Banner["default"], {
        classes: classes
      }));
      expect(wrapper.find("Banner").childAt(0).find("div").hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClass decorator", function () {
      var classes = ["riipen", "riipen-banner"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Banner["default"], null));
      expect(wrapper.find("Banner").props().classes.sort()).toEqual(classes.sort());
    });
    it("gives an error when classes are provided as one string", function () {
      var classes = "classOne classTwo";
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Banner["default"], {
        classes: classes
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("height prop", function () {
    it("sets the div inside Banner to a given height", function () {
      var height = "50px";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Banner["default"], {
        height: height
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain(height);
    });
    it("gives an error when height is not given as a string", function () {
      var height = 50;
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Banner["default"], {
        height: height
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("src prop", function () {
    it("sets background image with given src value", function () {
      var src = "/static/images/banners/folders.jpg";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Banner["default"], {
        src: src
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain(src);
    });
  });
  describe("tint prop", function () {
    it("applies tint class name given valid tint", function () {
      var tint = "tertiary";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Banner["default"], {
        tint: tint
      }));
      expect(wrapper.find("Banner").childAt(0).find("div").hasClass(tint)).toEqual(true);
    });
    it("gives an error when given an invalid tint", function () {
      var tint = "hi hi hi";
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Banner["default"], {
        tint: tint
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
});