"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _Breadcrumbs = _interopRequireDefault(require("./Breadcrumbs.jsx"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Breadcrumbs>", function () {
  it("renders without errors", function () {
    var error;

    var child = /*#__PURE__*/_react["default"].createElement("h1", null, "hello hello");

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Breadcrumbs["default"], null, child));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var child = /*#__PURE__*/_react["default"].createElement("h1", null, "hello hello");

    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Breadcrumbs["default"], null, child));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var child = /*#__PURE__*/_react["default"].createElement("h1", null, "hello hello");

      var defaultProps = new _Breadcrumbs["default"]({
        children: child
      }).type.defaultProps;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Breadcrumbs["default"], null, child));
      var component = wrapper.find("Breadcrumbs");
      expect(component.props().component).toEqual(defaultProps.component);
      expect(component.props().separator).toEqual(defaultProps.separator);
    });
  });
  describe("children prop", function () {
    it("renders children nodes as a list", function () {
      var child1 = /*#__PURE__*/_react["default"].createElement("h1", null, "hello hello");

      var child2 = /*#__PURE__*/_react["default"].createElement("h1", null, "hello 2");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Breadcrumbs["default"], null, child1, child2));
      var list = wrapper.find("Breadcrumbs").find("Typography").find("ol").find("li");
      expect(list.at(0).contains(child1)).toEqual(true);
      expect(list.at(2).contains(child2)).toEqual(true);
    });
    it("assigns children nodes unique keys", function () {
      var child1 = /*#__PURE__*/_react["default"].createElement("h1", null, "hello hello");

      var child2 = /*#__PURE__*/_react["default"].createElement("h1", null, "hello 2");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Breadcrumbs["default"], null, child1, " ", child2));
      var list = wrapper.find("Breadcrumbs").find("Typography").find("ol").find("li");
      expect(list.at(0).key()).not.toEqual(list.at(2).key());
    });
  });
  describe("classes prop", function () {
    it("applies all classes to the ol element", function () {
      var classes = ["classOne"];

      var child = /*#__PURE__*/_react["default"].createElement("h1", null, "hello hello");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Breadcrumbs["default"], {
        classes: classes
      }, child));
      expect(wrapper.find("Breadcrumbs").childAt(0).find("ol").hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClass decorator", function () {
      var classes = ["riipen", "riipen-breadcrumbs"];

      var child = /*#__PURE__*/_react["default"].createElement("h1", null, "hello hello");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Breadcrumbs["default"], null, child));
      expect(wrapper.find("Breadcrumbs").props().classes.sort()).toEqual(classes.sort());
    });
    it("gives an error when classes are provided as one string", function () {
      var classes = "classOne classTwo";

      var child = /*#__PURE__*/_react["default"].createElement("h1", null, "hello hello");

      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Breadcrumbs["default"], {
        classes: classes
      }, child));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("component prop", function () {
    it("passes given value into the component prop of Typography", function () {
      var component = "h1";

      var child = /*#__PURE__*/_react["default"].createElement("h1", null, "hello hello");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Breadcrumbs["default"], {
        component: component
      }, child));
      expect(wrapper.find("Breadcrumbs").find("Typography").props().component).toEqual(component);
    });
  });
  describe("separator prop", function () {
    it("separates children nodes with default separator", function () {
      var child1 = /*#__PURE__*/_react["default"].createElement("h1", null, "hello hello");

      var child2 = /*#__PURE__*/_react["default"].createElement("h1", null, "hello 2");

      var defaultSeparator = new _Breadcrumbs["default"]({
        children: [child1, child2]
      }).type.defaultProps.separator;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Breadcrumbs["default"], null, child1, child2));
      var list = wrapper.find("Breadcrumbs").find("Typography").find("ol").find("li");
      expect(list.at(0).contains(child1)).toEqual(true);
      expect(list.at(1).text()).toEqual(defaultSeparator);
      expect(list.at(2).contains(child2)).toEqual(true);
    });
    it("separates children nodes with custom separator", function () {
      var child1 = /*#__PURE__*/_react["default"].createElement("h1", null, "hello hello");

      var child2 = /*#__PURE__*/_react["default"].createElement("h1", null, "hello 2");

      var separator = "mmm";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Breadcrumbs["default"], {
        separator: separator
      }, child1, child2));
      var list = wrapper.find("Breadcrumbs").find("Typography").find("ol").find("li");
      expect(list.at(0).contains(child1)).toEqual(true);
      expect(list.at(1).text()).toEqual(separator);
      expect(list.at(2).contains(child2)).toEqual(true);
    });
  });
});