"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _reactFontawesome = require("@fortawesome/react-fontawesome");

var _freeSolidSvgIcons = require("@fortawesome/free-solid-svg-icons");

var _Button = _interopRequireDefault(require("./Button"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var icon = function icon(i) {
  return function (props) {
    return /*#__PURE__*/_react["default"].createElement(_reactFontawesome.FontAwesomeIcon, _extends({
      icon: i
    }, props));
  };
};

describe("<Button>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], null));
    } catch (theError) {
      error = theError;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        value: true
      }));
      expect(wrapper.find("Button").props().classes).toEqual([]);
      expect(wrapper.find("Button").props().color).toEqual("default");
      expect(wrapper.find("Button").props().disabled).toEqual(false);
      expect(wrapper.find("Button").props().fullWidth).toEqual(false);
      expect(wrapper.find("Button").props().size).toEqual("medium");
      expect(wrapper.find("Button").props().type).toEqual("button");
      expect(wrapper.find("Button").props().variant).toEqual("text");
    });
  });
  describe("children prop", function () {
    it("displays given children", function () {
      var child = /*#__PURE__*/_react["default"].createElement("div", null, "child");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], null, child));
      expect(wrapper.containsMatchingElement(child)).toBeTruthy();
    });
  });
  describe("classes prop", function () {
    it("sets custom class", function () {
      var classes = ["newClass"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        classes: classes
      }));
      expect(wrapper.find("Button").childAt(0).hasClass(classes[0])).toEqual(true);
    });
  });
  describe("color prop", function () {
    it("gives an error when given an invalid color", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var color = "blue";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        color: color
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("component prop", function () {
    it("sets custom component", function () {
      var component = "a";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        component: component
      }));
      expect(wrapper.find("Button").childAt(0).name()).toEqual(component);
    });
    it("sets component type to button when component prop is not provided", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], null));
      expect(wrapper.find("Button").childAt(0).name()).toEqual("button");
    });
    it("gives an error when given an invalid component", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var component = "abcd";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        component: component
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("disabled prop", function () {
    it("sets disabled class name with valid custom disabled", function () {
      var disabled = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        disabled: disabled
      }));
      expect(wrapper.find("Button").childAt(0).hasClass("disabled")).toEqual(true);
    });
    it("sets valid custom disabled", function () {
      var disabled = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        disabled: disabled
      }));
      expect(wrapper.find("Button").childAt(0).props().disabled).toEqual(disabled);
    });
  });
  describe("fullWidth prop", function () {
    it("sets fullWidth class name with valid custom fullWidth", function () {
      var fullWidth = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        fullWidth: fullWidth
      }));
      expect(wrapper.find("Button").childAt(0).hasClass("full-width")).toEqual(true);
    });
  });
  describe("href prop", function () {
    it("sets custom href", function () {
      var href = "https://ui.riipen.com/";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        href: href
      }));
      expect(wrapper.find("Button").childAt(0).name()).toEqual("a");
    });
  });
  describe("iconEnd prop", function () {
    it("sets iconEnd class name with valid custom iconEnd", function () {
      var iconEnd = icon(_freeSolidSvgIcons.faTrash);
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        iconEnd: iconEnd
      }));
      expect(wrapper.find(".label").childAt(0).hasClass("icon-end")).toEqual(true);
    });
    it("renders iconEnd with a component icon", function () {
      var iconEnd = icon(_freeSolidSvgIcons.faTrash);
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        iconEnd: iconEnd
      }));
      expect(wrapper.find(".icon-end").childAt(0).childAt(0).name()).toEqual("FontAwesomeIcon");
    });
    it("renders iconEnd with a jsx icon", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        iconEnd: /*#__PURE__*/_react["default"].createElement(_reactFontawesome.FontAwesomeIcon, {
          icon: _freeSolidSvgIcons.faTrash
        })
      }));
      expect(wrapper.find(".icon-end").childAt(0).name()).toEqual("FontAwesomeIcon");
    });
  });
  describe("iconStart prop", function () {
    it("sets iconStart class name with valid custom iconStart", function () {
      var iconStart = icon(_freeSolidSvgIcons.faTrash);
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        iconStart: iconStart
      }));
      expect(wrapper.find(".label").childAt(0).hasClass("icon-start")).toEqual(true);
    });
    it("renders iconStart with a component icon", function () {
      var iconStart = icon(_freeSolidSvgIcons.faTrash);
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        iconStart: iconStart
      }));
      expect(wrapper.find(".icon-start").childAt(0).childAt(0).name()).toEqual("FontAwesomeIcon");
    });
    it("renders iconStart with a jsx icon", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        iconStart: /*#__PURE__*/_react["default"].createElement(_reactFontawesome.FontAwesomeIcon, {
          icon: _freeSolidSvgIcons.faTrash
        })
      }));
      expect(wrapper.find(".icon-start").childAt(0).name()).toEqual("FontAwesomeIcon");
    });
  });
  describe("size prop", function () {
    it("sets size class name with valid custom size", function () {
      var size = "large";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        size: size
      }));
      expect(wrapper.find("Button").childAt(0).hasClass(size)).toEqual(true);
    });
    it("gives an error when given an invalid size", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var size = "x-small";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        size: size
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("type prop", function () {
    it("sets custom valid type", function () {
      var type = "reset";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        type: type
      }));
      expect(wrapper.find("Button").childAt(0).props().type).toEqual(type);
    });
    it("gives an error when given an invalid type", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var type = "enter";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        type: type
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("variant prop", function () {
    it("sets contained variant class name for contained variant", function () {
      var variant = "contained";
      var color = "primary";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        variant: variant,
        color: color
      }));
      expect(wrapper.find("Button").childAt(0).hasClass("contained-".concat(color))).toEqual(true);
    });
    it("sets text and default variant class name for text variant", function () {
      var variant = "text";
      var color = "primary";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        variant: variant,
        color: color
      }));
      expect(wrapper.find("Button").childAt(0).hasClass("text-".concat(color))).toEqual(true);
      expect(wrapper.find("Button").childAt(0).hasClass(variant)).toEqual(true);
    });
    it("sets outlined variant class name for outlined variant", function () {
      var variant = "outlined";
      var color = "primary";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        variant: variant,
        color: color
      }));
      expect(wrapper.find("Button").childAt(0).hasClass("outlined-".concat(color))).toEqual(true);
    });
    it("sets inverted variant class name for inverted variant", function () {
      var variant = "inverted";
      var color = "primary";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        variant: variant,
        color: color
      }));
      expect(wrapper.find("Button").childAt(0).hasClass("inverted-".concat(color))).toEqual(true);
    });
    it("gives an error when given an invalid variant", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var variant = "default";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        variant: variant
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("focusVisible state", function () {
    it("sets correct class name when focus event occurs", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        value: true
      }));
      wrapper.find("button").invoke("onFocus")({});
      expect(wrapper.find("Button").childAt(0).hasClass("focusVisible")).toEqual(true);
    });
    it("sets correct class name when blur event occurs", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Button["default"], {
        value: true
      }));
      wrapper.find("button").invoke("onFocus")({});
      wrapper.find("button").invoke("onBlur")();
      expect(wrapper.find("Button").childAt(0).hasClass("focusVisible")).toEqual(false);
    });
  });
});