"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _ButtonBase = _interopRequireDefault(require("./ButtonBase"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

describe("ButtonBase component", function () {
  var props;
  var children;
  beforeEach(function () {
    children = /*#__PURE__*/_react["default"].createElement("div", null, "A child");
    props = {
      ariaLabel: "click to be cool"
    };
  });
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonBase["default"], props, children));
    } catch (theError) {
      error = theError;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonBase["default"], props, children));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonBase["default"], props, children));
      expect(wrapper.find("ButtonBase").props().classes).toEqual([]);
      expect(wrapper.find("ButtonBase").props().variant).toEqual("default");
      expect(wrapper.find("ButtonBase").props().type).toEqual("button");
    });
  });
  describe("children prop", function () {
    it("displays given children", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonBase["default"], props, children));
      expect(wrapper.containsMatchingElement(children)).toBeTruthy();
    });
  });
  describe("classes prop", function () {
    it("sets custom class", function () {
      props.classes = "newClass";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonBase["default"], props, children));
      expect(wrapper.find("ButtonBase").childAt(0).hasClass(props.classes)).toEqual(true);
    });
  });
  describe("variant prop", function () {
    it("applies variant class", function () {
      props.variant = "default";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonBase["default"], props, children));
      expect(wrapper.find("ButtonBase").props().variant).toEqual(props.variant);
      expect(wrapper.find("ButtonBase").find("button").hasClass(props.variant)).toEqual(true);
    });
  });
  describe("type prop", function () {
    it("applies type to button", function () {
      var type = "submit";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonBase["default"], _extends({}, props, {
        type: type
      }), children));
      expect(wrapper.find("ButtonBase").props().type).toEqual(type);
    });
  });
  describe("ariaLabel prop", function () {
    it("applies ariaLabel to button", function () {
      props.ariaLabel = "cool";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonBase["default"], props, children));
      expect(wrapper.find("ButtonBase").props().ariaLabel).toEqual(props.ariaLabel);
      expect(wrapper.find("button[aria-label='cool']")).toHaveLength(1);
    });
  });
});