"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _ButtonIcon = _interopRequireDefault(require("./ButtonIcon"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<ButtonIcon>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], null, "children"));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], null, "children"));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], null, "children"));
      var component = wrapper.find("ButtonIcon");
      expect(component.props().classes).toEqual(["riipen", "riipen-buttonicon"]);
      expect(component.props().color).toEqual("default");
      expect(component.props().disabled).toEqual(false);
      expect(component.props().size).toEqual("medium");
      expect(component.props().variant).toEqual("icon");
    });
  });
  describe("children prop", function () {
    it("displays given children", function () {
      var child = "children";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], null, child));
      expect(wrapper.find("ButtonIcon").contains(child)).toEqual(true);
    });
  });
  describe("classes prop", function () {
    it("applies custom classes", function () {
      var classes = ["classOne"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], {
        classes: classes
      }, "children"));
      expect(wrapper.find("ButtonIcon").childAt(0).hasClass(classes[0])).toEqual(true);
    });
  });
  describe("color prop", function () {
    it("sets color class name with a valid color", function () {
      var color = "secondary";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], {
        color: color
      }, "children"));
      expect(wrapper.find("ButtonIcon").childAt(0).hasClass("icon-".concat(color))).toEqual(true);
    });
    it("gives an error when given an invalid color", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], {
        color: "pink"
      }, "children"));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("component prop", function () {
    it("sets component with valid custom component", function () {
      var component = "span";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], {
        component: component
      }, "children"));
      expect(wrapper.find("ButtonIcon").childAt(0).name()).toEqual(component);
    });
    it("sets component type to button when component prop is not provided", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], null, "children"));
      expect(wrapper.find("ButtonIcon").childAt(0).name()).toEqual("button");
    });
    it("sets component type to a when href is defined", function () {
      var href = "www.google.com";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], {
        href: href
      }, "children"));
      expect(wrapper.find("ButtonIcon").childAt(0).name()).toEqual("a");
    });
    it("gives an error when given an invalid component", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var component = "abcd";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], {
        component: component
      }, "children"));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("disabled prop", function () {
    it("applies disabled class when disabled prop is true", function () {
      var disabled = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], {
        disabled: disabled
      }, "children"));
      expect(wrapper.find("ButtonIcon").childAt(0).hasClass("disabled")).toEqual(true);
    });
    it("does not apply disabled class when disabled prop is false", function () {
      var disabled = false;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], {
        disabled: disabled
      }, "children"));
      expect(wrapper.find("ButtonIcon").childAt(0).hasClass("disabled")).toEqual(false);
    });
    it("passes given disabled value to button", function () {
      var disabled = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], {
        disabled: disabled
      }, "children"));
      expect(wrapper.find("ButtonIcon").childAt(0).props().disabled).toEqual(disabled);
    });
  });
  describe("size prop", function () {
    it("sets font and icon with given valid custom size prop", function () {
      var size = "small";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], {
        size: size
      }, "children"));
      expect(wrapper.find("ButtonIcon").find("span").hasClass("icon-small")).toEqual(true);
      expect(wrapper.find("ButtonIcon").find("span").hasClass("font-small")).toEqual(true);
    });
    it("gives an error given invalid size", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var size = "sm";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], {
        size: size
      }, "children"));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("variant prop", function () {
    it("sets variant class name with a valid variant", function () {
      var variant = "outlined";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], {
        variant: variant
      }, "children"));
      expect(wrapper.find("ButtonIcon").childAt(0).hasClass("".concat(variant, "-default"))).toEqual(true);
    });
    it("gives an error when given an invalid variant", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], {
        variant: "bad"
      }, "children"));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("focusVisible state", function () {
    it("does not apply focusVisible class when component is rendered", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], null, "children"));
      expect(wrapper.find("ButtonIcon").childAt(0).hasClass("focusVisible")).toEqual(false);
    });
    it("applies focusVisible class when focus event occurs", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], null, "children"));
      wrapper.find("button").invoke("onFocus")({});
      expect(wrapper.find("ButtonIcon").childAt(0).hasClass("focusVisible")).toEqual(true);
    });
    it("does not apply focusVisible class when blur event occurs", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ButtonIcon["default"], null, "children"));
      wrapper.find("button").invoke("onFocus")({});
      wrapper.find("button").invoke("onBlur")();
      expect(wrapper.find("ButtonIcon").childAt(0).hasClass("focusVisible")).toEqual(false);
    });
  });
});