"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _Checkbox = _interopRequireDefault(require("./Checkbox"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Checkbox>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Checkbox["default"], {
        readOnly: true
      }));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Checkbox["default"], {
      readOnly: true
    }));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Checkbox["default"], {
        readOnly: true
      }));
      var component = wrapper.find("Checkbox");
      expect(component.props().checked).toEqual(false);
      expect(component.props().disabled).toEqual(false);
      expect(component.props().required).toEqual(false);
    });
  });
  describe("checked prop", function () {
    it("sets checked with given checked value", function () {
      var checked = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Checkbox["default"], {
        checked: checked,
        readOnly: true
      }));
      expect(wrapper.find("Checkbox").find("input").props().checked).toEqual(checked);
    });
  });
  describe("classes prop", function () {
    it("applies custom classes", function () {
      var classes = ["classOne"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Checkbox["default"], {
        classes: classes,
        readOnly: true
      }));
      expect(wrapper.find("Checkbox").childAt(0).hasClass(classes[0])).toEqual(true);
    });
  });
  describe("color prop", function () {
    it("sets color class name with a valid color", function () {
      var color = "secondary";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Checkbox["default"], {
        color: color,
        readOnly: true
      }));
      expect(wrapper.find("Checkbox").childAt(0).childAt(0).childAt(2).hasClass(color)).toEqual(true);
    });
    it("gives an error when given an invalid color", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Checkbox["default"], {
        color: "pink",
        readOnly: true
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("disabled prop", function () {
    it("sets disabled with given disabled value", function () {
      var disabled = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Checkbox["default"], {
        disabled: disabled,
        readOnly: true
      }));
      expect(wrapper.find("Checkbox").find("input").props().disabled).toEqual(disabled);
    });
    it("applies disabled class name when disabled is true", function () {
      var disabled = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Checkbox["default"], {
        disabled: disabled,
        readOnly: true
      }));
      expect(wrapper.find("Checkbox").find(".checkmark").hasClass("disabled")).toEqual(true);
    });
  });
  describe("error prop", function () {
    it("displays given error", function () {
      var error = /*#__PURE__*/_react["default"].createElement("span", null, "error!");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Checkbox["default"], {
        error: error,
        readOnly: true
      }));
      expect(wrapper.childAt(0).contains(error)).toEqual(true);
    });
  });
  describe("label prop", function () {
    it("displays given label in the label element", function () {
      var label = "this is a label";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Checkbox["default"], {
        label: label,
        readOnly: true
      }));
      expect(wrapper.find("label").contains(label)).toEqual(true);
    });
  });
  describe("required prop", function () {
    it("displays an asterisk at the end of the label when required is true", function () {
      var label = /*#__PURE__*/_react["default"].createElement("span", null, "this is a label");

      var required = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Checkbox["default"], {
        required: required,
        label: label,
        readOnly: true
      }));
      expect(wrapper.find("Checkbox").find("label").text().substr(-1)).toEqual("*");
    });
    it("does not display an asterisk when required is false", function () {
      var label = "this is a label";
      var required = false;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Checkbox["default"], {
        required: required,
        label: label,
        readOnly: true
      }));
      expect(wrapper.find("Checkbox").find("label").text().substr(-1)).not.toEqual("*");
    });
  });
  describe("warning prop", function () {
    it("displays given warning", function () {
      var warning = /*#__PURE__*/_react["default"].createElement("span", null, "warning!");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Checkbox["default"], {
        warning: warning,
        readOnly: true
      }));
      expect(wrapper.childAt(0).contains(warning)).toEqual(true);
    });
  });
  describe("focusVisible state", function () {
    it("applies focusVisible class when focus event occurs", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Checkbox["default"], {
        readOnly: true
      }));
      wrapper.find("input").invoke("onFocus")({});
      expect(wrapper.find("Checkbox").find("input").hasClass("focusVisible")).toEqual(true);
    });
    it("does not apply focusVisible class when blur event occurs", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Checkbox["default"], {
        readOnly: true
      }));
      wrapper.find("input").invoke("onFocus")({});
      wrapper.find("input").invoke("onBlur")();
      expect(wrapper.find("Checkbox").find("input").hasClass("focusVisible")).toEqual(false);
    });
  });
  describe("handleKeyDown event", function () {
    it("invokes handleKeyDown on valid keydown event", function () {
      var handler = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Checkbox["default"], {
        onKeyDown: handler,
        readOnly: true
      }));
      wrapper.find("input").invoke("onKeyDown")({
        key: "Enter"
      });
      expect(handler).toHaveBeenCalledTimes(1);
    });
  });
});