"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _Chip = _interopRequireDefault(require("./Chip"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Chip>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], null));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], null));
      var component = wrapper.find("Chip");
      expect(component.childAt(0).name()).toEqual("div");
      expect(component.props().color).toEqual("default");
      expect(component.props().disabled).toEqual(false);
      expect(component.props().hover).toEqual(false);
      expect(component.props().size).toEqual("medium");
      expect(component.props().variant).toEqual("default");
    });
  });
  describe("children prop", function () {
    it("displays label from child", function () {
      var label = "A label given as a child";

      var child = /*#__PURE__*/_react["default"].createElement("div", null, label);

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], null, child));
      expect(wrapper.find(".label").children().contains(child)).toEqual(true);
      expect(wrapper.find(".label").childAt(0).text()).toEqual(label);
    });
  });
  describe("classes prop", function () {
    it("applies all classes to the root node of Chip", function () {
      var classes = ["classOne"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        classes: classes
      }));
      expect(wrapper.find("Chip").childAt(0).hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClasses decorator", function () {
      var classes = ["riipen", "riipen-chip"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], null));
      expect(wrapper.find("Chip").props().classes.sort()).toEqual(classes.sort());
    });
    it("gives an error when classes are provided as one string", function () {
      var classes = "classOne classTwo";
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        classes: classes
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("color prop", function () {
    it("sets color class name with a valid color", function () {
      var color = "greyA400";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        color: color
      }));
      expect(wrapper.find("Chip").props().color).toEqual(color);
      expect(wrapper.find("Chip").childAt(0).hasClass(color)).toEqual(true);
    });
    it("gives an error when given an invalid color", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        color: "red"
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("component prop", function () {
    it("sets component with valid custom component", function () {
      var component = "a";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        component: component
      }));
      expect(wrapper.find(component)).toHaveLength(1);
      expect(wrapper.find("Chip").childAt(0).name()).toEqual(component);
    });
    it("gives an error when given an invalid component", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var component = "abcdefg";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        component: component
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("disabled prop", function () {
    it("applies disabled class when disabled prop is true", function () {
      var disabled = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        disabled: disabled
      }));
      expect(wrapper.find("Chip").childAt(0).hasClass("disabled")).toEqual(true);
    });
    it("does not apply disabled class when disabled prop is false", function () {
      var disabled = false;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        disabled: disabled
      }));
      expect(wrapper.find("Chip").childAt(0).hasClass("disabled")).toEqual(false);
    });
  });
  describe("hover prop", function () {
    it("applies hover class when hover prop is true", function () {
      var hover = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        hover: hover
      }));
      expect(wrapper.find("Chip").childAt(0).hasClass("hover")).toEqual(true);
    });
    it("does not apply hover class when hover prop is false", function () {
      var hover = false;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        hover: hover
      }));
      expect(wrapper.find("Chip").childAt(0).hasClass("hover")).toEqual(false);
    });
  });
  describe("icon prop", function () {
    it("displays icon when given", function () {
      var icon = /*#__PURE__*/_react["default"].createElement("span", null, "icon");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        icon: icon
      }));
      expect(wrapper.find(".icon").children().contains(icon)).toEqual(true);
    });
  });
  describe("label prop", function () {
    it("displays label from label prop", function () {
      var label = "A test label";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        label: label
      }));
      expect(wrapper.find("Chip").find("span").text()).toEqual(label);
    });
    it("prioritizes displaying label over children", function () {
      var label = "label";

      var child = /*#__PURE__*/_react["default"].createElement("div", null, "\"child\"");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        label: label
      }, child));
      expect(wrapper.find(".label").children().contains(child)).toEqual(false);
      expect(wrapper.find("Chip").find("span").text()).toEqual(label);
    });
  });
  describe("onClick prop", function () {
    it("sets clickable class name ", function () {
      var handler = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        onClick: handler
      }));
      expect(wrapper.find("Chip").childAt(0).hasClass("clickable")).toEqual(true);
    });
    it("invokes onClick handler when clicked", function () {
      var handler = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        onClick: handler
      }));
      wrapper.find("div").at(0).invoke("onClick")();
      expect(handler).toHaveBeenCalledTimes(1);
    });
  });
  describe("size prop", function () {
    it("sets size class name with a valid size", function () {
      var size = "small";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        size: size
      }));
      expect(wrapper.find("Chip").childAt(0).hasClass(size)).toEqual(true);
    });
    it("gives an error when given an invalid size", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var size = "large";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        size: size
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("variant prop", function () {
    it("sets variant class name with a valid variant", function () {
      var variant = "outlined";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        variant: variant
      }));
      expect(wrapper.find("Chip").childAt(0).hasClass(variant)).toEqual(true);
    });
    it("gives an error when given an invalid variant", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var variant = "somethingInvalid";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        variant: variant
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("focusVisible state", function () {
    it("applies focusVisible class when focus event occurs", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        label: "test"
      }));
      wrapper.find("div").at(0).invoke("onFocus")({});
      expect(wrapper.find("Chip").childAt(0).hasClass("focusVisible")).toEqual(true);
    });
    it("does not apply focusVisible class when blur event occurs", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Chip["default"], {
        label: "test"
      }));
      wrapper.find("div").at(0).invoke("onFocus")({});
      wrapper.find("div").at(0).invoke("onBlur")();
      expect(wrapper.find("Chip").childAt(0).hasClass("focusVisible")).toEqual(false);
    });
  });
});