"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _default = _interopRequireDefault(require("../themes/default"));

var _Container = _interopRequireDefault(require("./Container"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Container>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Container["default"], null));
    } catch (theError) {
      error = theError;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Container["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var defaultProps = new _Container["default"]().type.defaultProps;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Container["default"], null));
      expect(wrapper.find("Container").props().maxWidth).toEqual(defaultProps.maxWidth);
    });
  });
  describe("children prop", function () {
    it("displays given children", function () {
      var child = /*#__PURE__*/_react["default"].createElement("div", null, "child");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Container["default"], null, child));
      expect(wrapper.containsMatchingElement(child)).toBeTruthy();
    });
  });
  describe("classes prop", function () {
    it("sets custom class", function () {
      var classes = ["newClass"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Container["default"], {
        classes: classes
      }));
      expect(wrapper.find("Container").childAt(0).hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to default classes prop with withClass decorator", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Container["default"], null));
      expect(wrapper.find("Container").props().classes).toEqual(["riipen", "riipen-container"]);
    });
  });
  describe("maxWidth prop", function () {
    it("container renders with custom valid maxWidth", function () {
      var max = "md";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Container["default"], {
        maxWidth: max
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain("".concat(_default["default"].breakpoints[max], "px"));
    });
    it("container renders at 100% width", function () {
      var max = false;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Container["default"], {
        maxWidth: max
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain("100%");
    });
    it("throws an error with invalid maxWidth variant", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var maxWidth = "s";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Container["default"], {
        maxWidth: maxWidth
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
});