"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _Drawer = _interopRequireDefault(require("./Drawer.jsx"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Drawer>", function () {
  it("renders without errors", function () {
    var onClose = jest.fn();
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Drawer["default"], {
        onClose: onClose
      }));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders the correct snapshot when open is true and onClose is provided", function () {
    var open = true;
    var onClose = jest.fn();
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Drawer["default"], {
      open: open,
      onClose: onClose
    }));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var onClose = jest.fn();
      var defaultProps = new _Drawer["default"]({
        onClose: onClose
      }).type.defaultProps;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Drawer["default"], {
        onClose: onClose
      }));
      var component = wrapper.find("Drawer");
      expect(component.props().anchor).toEqual(defaultProps.anchor);
      expect(component.props().open).toEqual(defaultProps.open);
      expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
    });
  });
  describe("anchor prop", function () {
    it("sets anchor class name with a valid anchor and open prop is true", function () {
      var anchor = "bottom";
      var open = true;
      var onClose = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Drawer["default"], {
        anchor: anchor,
        open: open,
        onClose: onClose
      }));
      expect(wrapper.find("ClickAway").childAt(0).childAt(0).hasClass(anchor)).toEqual(true);
    });
    it("gives an error when given an invalid anchor", function () {
      var anchor = "leftright";
      var errors = jest.spyOn(console, "error").mockImplementation();
      var onClose = jest.fn();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Drawer["default"], {
        anchor: anchor,
        onClose: onClose
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("children prop", function () {
    it("passes children to the ClickAway component when open prop is true", function () {
      var child = /*#__PURE__*/_react["default"].createElement("h1", null, "The children prop");

      var open = true;
      var onClose = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Drawer["default"], {
        open: open,
        onClose: onClose
      }, child));
      expect(wrapper.find("ClickAway").contains(child)).toEqual(true);
    });
  });
  describe("classes prop", function () {
    it("applies all classes to the div inside of ClickAway", function () {
      var classes = ["classOne"];
      var open = true;
      var onClose = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Drawer["default"], {
        classes: classes,
        open: open,
        onClose: onClose
      }));
      expect(wrapper.find("ClickAway").childAt(0).childAt(0).hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClass decorator", function () {
      var classes = ["riipen", "riipen-drawer"];
      var onClose = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Drawer["default"], {
        onClose: onClose
      }));
      expect(wrapper.find("Drawer").props().classes.sort()).toEqual(classes.sort());
    });
    it("gives an error when classes are provided as one string", function () {
      var classes = "classOne classTwo";
      var onClose = jest.fn();
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Drawer["default"], {
        classes: classes,
        onClose: onClose
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("onClose prop", function () {
    it("passes onClose handler to ClickAway", function () {
      var open = true;
      var onClose = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Drawer["default"], {
        open: open,
        onClose: onClose
      }));
      expect(wrapper.find("ClickAway").props().onClickAway).toEqual(onClose);
    });
    it("invokes onClose handler when component requests to be closed", function () {
      var open = true;
      var onClose = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Drawer["default"], {
        open: open,
        onClose: onClose
      }));
      wrapper.find("ClickAway").invoke("onClickAway")();
      expect(onClose).toHaveBeenCalledTimes(1);
    });
    it("gives a console error when onClose prop is not provided", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Drawer["default"], null));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("open prop", function () {
    it("renders contents of the component when open is true", function () {
      var open = true;
      var onClose = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Drawer["default"], {
        open: open,
        onClose: onClose
      }));
      expect(wrapper.find("Drawer").children()).not.toHaveLength(0);
      expect(wrapper.find("Backdrop")).toHaveLength(1);
      expect(wrapper.find("ClickAway")).toHaveLength(1);
    });
    it("does not render contents of the component when open is false", function () {
      var open = false;
      var onClose = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Drawer["default"], {
        open: open,
        onClose: onClose
      }));
      expect(wrapper.find("Drawer").children()).toHaveLength(0);
    });
  });
});