"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _Form = _interopRequireDefault(require("./Form"));

var _Typography = _interopRequireDefault(require("./Typography"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Form>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Form["default"], null));
    } catch (theError) {
      error = theError;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Form["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Form["default"], null));
      expect(wrapper.find("Form").props().enter).toEqual(true);
      expect(wrapper.find("Form").props().errorScroll).toEqual(true);
    });
  });
  describe("children prop", function () {
    it("displays given children", function () {
      var child = /*#__PURE__*/_react["default"].createElement("div", null, "child");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Form["default"], null, child));
      expect(wrapper.containsMatchingElement(child)).toBeTruthy();
    });
  });
  describe("classes prop", function () {
    it("sets custom class", function () {
      var classes = ["newClass"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Form["default"], {
        classes: classes
      }));
      expect(wrapper.find("Form").childAt(0).hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClass decorator", function () {
      var classes = ["riipen", "riipen-form"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Form["default"], null));
      expect(wrapper.find("Form").props().classes).toEqual(classes.sort());
    });
  });
  describe("error prop", function () {
    var props = {};
    var tests = [{
      argument: "Error"
    }, {
      argument: /*#__PURE__*/_react["default"].createElement(_Typography["default"], null, "Please provide a name")
    }];
    tests.forEach(function (test) {
      it("sets class name as error with valid custom error type", function () {
        props.error = test.argument;
        var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Form["default"], {
          error: props.error
        }));
        expect(wrapper.find("Notice").childAt(0).childAt(0).hasClass("error")).toEqual(true);
      });
    });
    it("sets class name as errorContainer when valid error is used", function () {
      var error = "Yay";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Form["default"], {
        error: error
      }));
      expect(wrapper.find("Form").childAt(0).hasClass("errorContainer")).toEqual(true);
    });
    it("renders error", function () {
      var error = "Yay";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Form["default"], {
        error: error
      }));
      expect(wrapper.find("Form").text()).toEqual(error);
    });
    it("renders error within Typography element if error is a string", function () {
      var error = "Yay";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Form["default"], {
        error: error
      }));
      expect(wrapper.find("Typography").contains(error)).toEqual(true);
    });
    it("renders error as given element", function () {
      var error = /*#__PURE__*/_react["default"].createElement(_Typography["default"], null, "Please provide a name");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Form["default"], {
        error: error
      }));
      expect(wrapper.find("Typography").contains(error)).toEqual(false);
      expect(wrapper.find("Form").props().error.type).toEqual(_Typography["default"]);
    });
  });
  describe("errors prop", function () {
    var props = {};
    var tests = [{
      argument: ["Error", "Sad"]
    }, {
      argument: {
        errorOne: "Error",
        errorTwo: "Sad"
      }
    }, {
      argument: [/*#__PURE__*/_react["default"].createElement(_Typography["default"], null, "Please provide a name"), /*#__PURE__*/_react["default"].createElement(_Typography["default"], null, "Error")]
    }];
    tests.forEach(function (test) {
      it("sets class name as errors with valid custom errors type", function () {
        props.errors = test.argument;
        var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Form["default"], {
          errors: props.errors
        }));
        expect(wrapper.find("Notice").childAt(0).childAt(0).hasClass("errors")).toEqual(true);
      });
    });
    it("sets class name as errorContainer when valid errors are used", function () {
      var errors = ["Error", "Sad"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Form["default"], {
        errors: errors
      }));
      expect(wrapper.find("Form").childAt(0).hasClass("errorContainer")).toEqual(true);
    });
    it("does not set errorContainer class name without valid errors", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Form["default"], null));
      expect(wrapper.find("Form").childAt(0).hasClass("errorContainer")).toEqual(false);
    });
    it("renders errors from given string array", function () {
      var errors = ["Error", "Sad"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Form["default"], {
        errors: errors
      }));
      expect(wrapper.find(".errors").childAt(0).childAt(0).childAt(0).childAt(0).text()).toEqual(errors[0]);
      expect(wrapper.find(".errors").childAt(1).childAt(0).childAt(0).childAt(0).text()).toEqual(errors[1]);
    });
    it("renders errors from given object", function () {
      var errors = {
        Error: "Please provide more cheese",
        Warning: "Minimum cheese added"
      };
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Form["default"], {
        errors: errors
      }));
      expect(wrapper.find(".errors").childAt(0).childAt(0).childAt(0).childAt(0).text()).toEqual("Error: Please provide more cheese");
      expect(wrapper.find(".errors").childAt(1).childAt(0).childAt(0).childAt(0).text()).toEqual("Warning: Minimum cheese added");
    });
  });
});