"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _default = _interopRequireDefault(require("../themes/default"));

var _Grid = _interopRequireDefault(require("./Grid.jsx"));

var _GridItem = _interopRequireDefault(require("./GridItem.jsx"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Grid>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], null));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var defaultProps = new _Grid["default"]().type.defaultProps;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], null));
      var component = wrapper.find("Grid");
      expect(component.props().alignItems).toEqual(defaultProps.alignItems);
      expect(component.props().justifyContent).toEqual(defaultProps.justifyContent);
      expect(component.props().spacing).toEqual(defaultProps.spacing);
      expect(component.props().flexGrow).toEqual(defaultProps.flexGrow);
      expect(component.props().flexShrink).toEqual(defaultProps.flexShrink);
      expect(component.props().flexDirection).toEqual(defaultProps.flexDirection);
      expect(component.props().flexWrap).toEqual(defaultProps.flexWrap);
      expect(component.props().onResize).toEqual(defaultProps.onResize);
    });
  });
  describe("alignItems prop", function () {
    it("sets given valid custom alignItems", function () {
      var alignItems = "stretch";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], {
        alignItems: alignItems
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain(alignItems);
    });
    it("gives an error given an invalid alignItems", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var alignItems = "middle";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], {
        alignItems: alignItems
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("children prop", function () {
    it("renders given non null children", function () {
      var child = /*#__PURE__*/_react["default"].createElement(_GridItem["default"], null);

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], null, null, child));
      expect(wrapper.find("Grid").childAt(0).containsMatchingElement(child)).toEqual(true);
    });
    it("passes spacing to children nodes", function () {
      var child = /*#__PURE__*/_react["default"].createElement(_GridItem["default"], null);

      var spacing = 0;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], {
        spacing: spacing
      }, child));
      expect(wrapper.find("GridItem").props().spacing).toEqual(spacing);
    });
    it("passes size to children nodes", function () {
      var size = "sm";

      var child = /*#__PURE__*/_react["default"].createElement(_GridItem["default"], null);

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], null, child));
      wrapper.find("Grid").setState({
        size: size
      });
      expect(wrapper.find("GridItem").props().size).toEqual(size);
    });
  });
  describe("classes prop", function () {
    it("applies custom classes", function () {
      var classes = ["classOne"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], {
        classes: classes
      }));
      expect(wrapper.find("Grid").childAt(0).hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClass decorator", function () {
      var classes = ["riipen", "riipen-grid"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], null));
      expect(wrapper.find("Grid").props().classes.sort()).toEqual(classes.sort());
    });
  });
  describe("flexDirection prop", function () {
    it("sets given valid custom flexDirection", function () {
      var flexDirection = "column-reverse";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], {
        flexDirection: flexDirection
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain(flexDirection);
    });
    it("gives an error given an invalid flexDirection", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var flexDirection = "middle";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], {
        flexDirection: flexDirection
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("flexGrow prop", function () {
    it("sets given custom flexGrow", function () {
      var flexGrow = 100;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], {
        flexGrow: flexGrow
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain(flexGrow);
    });
  });
  describe("flexShrink prop", function () {
    it("sets given custom flexShrink", function () {
      var flexShrink = 100;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], {
        flexShrink: flexShrink
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain(flexShrink);
    });
  });
  describe("flexWrap prop", function () {
    it("sets given custom flexWrap", function () {
      var flexWrap = "unset";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], {
        flexWrap: flexWrap
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain(flexWrap);
    });
    it("gives an error given an invalid flexWrap", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var flexWrap = "middle";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], {
        flexWrap: flexWrap
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("justifyContent prop", function () {
    it("sets given custom justifyContent", function () {
      var justifyContent = "center";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], {
        justifyContent: justifyContent
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain(justifyContent);
    });
    it("gives an error given an invalid justifyContent", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var justifyContent = "middle";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], {
        justifyContent: justifyContent
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("spacing prop", function () {
    it("sets given custom spacing", function () {
      var spacing = 10;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], {
        spacing: spacing
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain(_default["default"].spacing(spacing));
    });
    it("gives an error given an invalid spacing", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var spacing = 20;
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], {
        spacing: spacing
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("onResize prop", function () {
    it("invokes onResize function on mount", function () {
      var onResize = jest.fn();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Grid["default"], {
        onResize: onResize
      }));
      expect(onResize).toHaveBeenCalledTimes(1);
    });
  });
});