"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _default = _interopRequireDefault(require("../themes/default"));

var _GridItem = _interopRequireDefault(require("./GridItem"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<GridItem>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], null));
    } catch (theError) {
      error = theError;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var defaultProps = new _GridItem["default"]().type.defaultProps;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], null));
      expect(wrapper.find("GridItem").props().alignItems).toEqual(defaultProps.alignItems);
      expect(wrapper.find("GridItem").props().lg).toEqual(defaultProps.lg);
      expect(wrapper.find("GridItem").props().spacing).toEqual(defaultProps.spacing);
      expect(wrapper.find("GridItem").props().flexGrow).toEqual(defaultProps.flexGrow);
      expect(wrapper.find("GridItem").props().flexShrink).toEqual(defaultProps.flexShrink);
      expect(wrapper.find("GridItem").props().flexDirection).toEqual(defaultProps.flexDirection);
      expect(wrapper.find("GridItem").props().flexWrap).toEqual(defaultProps.flexWrap);
      expect(wrapper.find("GridItem").props().justifyContent).toEqual(defaultProps.justifyContent);
      expect(wrapper.find("GridItem").props().size).toEqual(defaultProps.size);
    });
  });
  describe("alignItems prop", function () {
    it("sets valid custom alignItems", function () {
      var alignItems = "center";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], {
        alignItems: alignItems
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain(alignItems);
    });
    it("gives an error when given an invalid alignItem", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var alignItems = "left";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], {
        alignItems: alignItems
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("children prop", function () {
    it("displays given children", function () {
      var child = /*#__PURE__*/_react["default"].createElement("div", null, "child");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], null, child));
      expect(wrapper.containsMatchingElement(child)).toBeTruthy();
    });
  });
  describe("classes prop", function () {
    it("sets custom class", function () {
      var classes = ["newClass"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], {
        classes: classes
      }));
      expect(wrapper.find("GridItem").childAt(0).hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClass decorator", function () {
      var classes = ["riipen", "riipen-griditem"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], null));
      expect(wrapper.find("GridItem").props().classes).toEqual(classes.sort());
    });
  });
  describe("flexDirection prop", function () {
    it("sets valid custom  flexDirection", function () {
      var flexDirection = "initial";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], {
        flexDirection: flexDirection
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain(flexDirection);
    });
    it("gives an error when given an invalid flexDirection", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var flexDirection = "reverse";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], {
        flexDirection: flexDirection
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("flexGrow prop", function () {
    it("sets valid custom flexGrow", function () {
      var flexGrow = 5;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], {
        flexGrow: flexGrow
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain(flexGrow);
    });
  });
  describe("flexShrink prop", function () {
    it("sets valid custom flexShrink", function () {
      var flexShrink = 5;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], {
        flexShrink: flexShrink
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain(flexShrink);
    });
  });
  describe("flexWrap prop", function () {
    it("sets valid custom  flexWrap", function () {
      var flexWrap = "unset";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], {
        flexWrap: flexWrap
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain(flexWrap);
    });
    it("gives an error when given an invalid flexWrap", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var flexWrap = "reverse";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], {
        flexWrap: flexWrap
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("justifyContent prop", function () {
    it("sets valid custom justifyContent", function () {
      var justifyContent = "space-between";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], {
        justifyContent: justifyContent
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain(justifyContent);
    });
    it("gives an error when given an invalid justifyContent", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var justifyContent = "space";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], {
        justifyContent: justifyContent
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("lg prop", function () {
    var props = {};
    var tests = [{
      argument: "hidden",
      expected: "none"
    }, {
      argument: "auto",
      expected: "flex"
    }, {
      argument: 7,
      expected: "flex"
    }];
    tests.forEach(function (test) {
      it("sets lg prop with custom valid type ".concat(test.argument), function () {
        props.size = "lg";
        props.lg = test.argument;
        var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], props));
        expect(wrapper.find("JSXStyle").props().dynamic).toContain(test.expected);
      });
    });
    it("gives an error when given an invalid lg", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var size = "lg";
      var lg = "hide";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], {
        size: size,
        lg: lg
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("md prop", function () {
    var props = {};
    var tests = [{
      argument: "hidden",
      expected: "none"
    }, {
      argument: "auto",
      expected: "flex"
    }, {
      argument: 5,
      expected: "flex"
    }];
    tests.forEach(function (test) {
      it("sets md prop with custom valid type ".concat(test.argument), function () {
        props.size = "md";
        props.md = test.argument;
        var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], props));
        expect(wrapper.find("JSXStyle").props().dynamic).toContain(test.expected);
      });
    });
    it("gives an error when given an invalid md", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var size = "md";
      var md = "hide";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], {
        size: size,
        md: md
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("sm prop", function () {
    var props = {};
    var tests = [{
      argument: "hidden",
      expected: "none"
    }, {
      argument: "auto",
      expected: "flex"
    }, {
      argument: 3,
      expected: "flex"
    }];
    tests.forEach(function (test) {
      it("sets sm prop with custom valid type ".concat(test.argument), function () {
        props.size = "sm";
        props.sm = test.argument;
        var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], props));
        expect(wrapper.find("JSXStyle").props().dynamic).toContain(test.expected);
      });
    });
    it("gives an error when given an invalid sm", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var size = "sm";
      var sm = "hide";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], {
        size: size,
        sm: sm
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("spacing prop", function () {
    it("sets custom spacing for the grid item", function () {
      var spacing = 2;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], {
        spacing: spacing
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain(_default["default"].spacing(spacing));
    });
    it("gives an error when given an invalid spacing", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var spacing = 12;
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], {
        spacing: spacing
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("size prop", function () {
    it("sets custom valid size", function () {
      var size = "md";
      var md = 3;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], {
        size: size,
        md: md
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain("flex");
    });
    it("gives an error when given an invalid size", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var size = "xl";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], {
        size: size
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("xs prop", function () {
    var props = {};
    var tests = [{
      argument: "hidden",
      expected: "none"
    }, {
      argument: "auto",
      expected: "flex"
    }, {
      argument: 1,
      expected: "flex"
    }];
    tests.forEach(function (test) {
      it("sets xs prop with custom valid type ".concat(test.argument), function () {
        props.size = "xs";
        props.xs = test.argument;
        var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], props));
        expect(wrapper.find("JSXStyle").props().dynamic).toContain(test.expected);
      });
    });
    it("gives an error when given an invalid xs", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var size = "xs";
      var xs = "hide";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_GridItem["default"], {
        size: size,
        xs: xs
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
});