"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _Hidden = _interopRequireDefault(require("./Hidden.jsx"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Hidden>", function () {
  it("renders without errors", function () {
    var error;
    var size = "sm";

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Hidden["default"], {
        size: size
      }));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var size = "sm";
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Hidden["default"], {
      size: size
    }));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var size = "sm";
      var defaultProps = new _Hidden["default"]({
        size: size
      }).type.defaultProps;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Hidden["default"], {
        size: size
      }));
      var component = wrapper.find("Hidden");
      expect(component.props().direction).toEqual(defaultProps.direction);
    });
  });
  describe("children prop", function () {
    it("displays given children", function () {
      var child = /*#__PURE__*/_react["default"].createElement("h1", null, "this is a child");

      var size = "sm";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Hidden["default"], {
        size: size
      }, child));
      expect(wrapper.find("Hidden").find("div").contains(child)).toEqual(true);
    });
  });
  describe("direction prop", function () {
    it("applies given direction to the size-direction className on div", function () {
      var direction = "up";
      var size = "sm";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Hidden["default"], {
        direction: direction,
        size: size
      }));
      expect(wrapper.find("Hidden").find("div").hasClass(new RegExp(".+-".concat(direction)))).toEqual(true);
    });
    it("gives an error given an invalid direction", function () {
      var direction = "left";
      var size = "sm";
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Hidden["default"], {
        size: size,
        direction: direction
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("size prop", function () {
    it("applies given size to the size-direction className on div", function () {
      var size = "sm";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Hidden["default"], {
        size: size
      }));
      expect(wrapper.find("Hidden").find("div").hasClass(new RegExp("".concat(size, "-.+")))).toEqual(true);
    });
    it("gives an error given an invalid size", function () {
      var size = "xxl";
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Hidden["default"], {
        size: size
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
});