"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _Input = _interopRequireDefault(require("./Input"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Input>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], null));
    } catch (theError) {
      error = theError;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], null));
      expect(wrapper.find("Input").props().disabled).toEqual(false);
      expect(wrapper.find("Input").props().multiline).toEqual(false);
    });
  });
  describe("classes prop", function () {
    it("sets custom class", function () {
      var classes = ["newClass"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        classes: classes
      }));
      expect(wrapper.find("Input").childAt(0).hasClass(classes[0])).toEqual(true);
    });
  });
  describe("disabled prop", function () {
    it("sets disabled class name when disabled prop is true", function () {
      var disabled = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        disabled: disabled
      }));
      expect(wrapper.find("Input").childAt(0).childAt(0).hasClass("disabled")).toEqual(true);
    });
    it("sets valid custom disabled", function () {
      var disabled = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        disabled: disabled
      }));
      expect(wrapper.find("Input").childAt(0).childAt(0).props().disabled).toEqual(disabled);
    });
  });
  describe("endAdornment prop", function () {
    it("renders custom endAdornment", function () {
      var endAdornment = "endAdornment";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        endAdornment: endAdornment
      }));
      expect(wrapper.text()).toContain(endAdornment);
    });
    it("sets correct endAdornment classes", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        endAdornment: "endAdornment"
      }));
      expect(wrapper.find("input").hasClass("endPadding")).toEqual(true);
    });
  });
  describe("error prop", function () {
    it("sets valid custom error", function () {
      var error = /*#__PURE__*/_react["default"].createElement("span", null, "Error");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        error: error
      }));
      expect(wrapper.find("Input").childAt(0).childAt(0).hasClass("error")).toEqual(true);
    });
    it("renders error", function () {
      var error = /*#__PURE__*/_react["default"].createElement("span", null, "Error");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        error: error
      }));
      expect(wrapper.find("Typography").contains(error)).toEqual(true);
    });
  });
  describe("hint prop", function () {
    it("sets valid custom hint", function () {
      var hint = "Test";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        hint: hint
      }));
      expect(wrapper.find("InputLabel").props().hint).toEqual(hint);
    });
    it("renders hint", function () {
      var hint = "Test";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        hint: hint
      }));
      expect(wrapper.text()).toEqual(hint);
    });
    it("does not render InputLabel element when hint is not given", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], null));
      expect(wrapper.find("Input").children().contains("InputLabel")).toEqual(false);
    });
  });
  describe("startAdornment prop", function () {
    it("renders custom startAdornment", function () {
      var startAdornment = "startAdornment";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        startAdornment: startAdornment
      }));
      expect(wrapper.text()).toContain(startAdornment);
    });
    it("sets correct startAdornment classes", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        startAdornment: "startAdornment"
      }));
      expect(wrapper.find("input").hasClass("startPadding")).toEqual(true);
    });
  });
  describe("label prop", function () {
    it("sets valid custom label", function () {
      var label = "Test";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        label: label
      }));
      expect(wrapper.find("InputLabel").props().children).toEqual(label);
    });
    it("renders label", function () {
      var label = "Test";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        label: label
      }));
      expect(wrapper.text()).toEqual(label);
    });
    it("does not render InputLabel element when label is not given", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], null));
      expect(wrapper.find("Input").children().contains("InputLabel")).toEqual(false);
    });
  });
  describe("labelProps prop", function () {
    it("passes props to InputLabel", function () {
      var label = "Test";
      var labelProps = {
        color: "black",
        variant: "h2"
      };
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        label: label,
        labelProps: labelProps
      }));
      expect(wrapper.find("InputLabel").props().color).toEqual("black");
      expect(wrapper.find("InputLabel").props().variant).toEqual("h2");
    });
  });
  describe("meta prop", function () {
    it("renders meta", function () {
      var meta = /*#__PURE__*/_react["default"].createElement("span", null, "Meta");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        meta: meta
      }));
      expect(wrapper.find("Typography").contains(meta)).toEqual(true);
    });
  });
  describe("multiline prop", function () {
    it("sets component as textarea with true multiline prop", function () {
      var multiline = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        multiline: multiline
      }));
      expect(wrapper.find("Input").childAt(0).childAt(0).name()).toEqual("textarea");
    });
    it("sets component as input with default multiline prop", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], null));
      expect(wrapper.find("Input").childAt(0).childAt(0).name()).toEqual("input");
    });
  });
  describe("required prop", function () {
    it("sets valid custom required", function () {
      var label = "Test";
      var required = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        label: label,
        required: required
      }));
      expect(wrapper.find("InputLabel").props().required).toEqual(required);
    });
  });
  describe("size prop", function () {
    it("sets valid size", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        size: "small"
      }));
      expect(wrapper.find("input").hasClass("small")).toEqual(true);
    });
  });
  describe("variant prop", function () {
    it("sets valid variant", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        variant: "underlined"
      }));
      expect(wrapper.find("input").hasClass("underlined")).toEqual(true);
    });
  });
  describe("warning prop", function () {
    it("sets valid custom warning", function () {
      var warning = /*#__PURE__*/_react["default"].createElement("span", null, "Error");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        warning: warning
      }));
      expect(wrapper.find("Input").childAt(0).childAt(0).hasClass("warning")).toEqual(true);
    });
    it("renders warning", function () {
      var warning = /*#__PURE__*/_react["default"].createElement("span", null, "Error");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        warning: warning
      }));
      expect(wrapper.find("Typography").contains(warning)).toEqual(true);
    });
  });
  describe("onFocus prop", function () {
    it("calls onFocus prop", function () {
      var onFocus = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        onFocus: onFocus
      }));
      wrapper.find("input").last().invoke("onFocus")({});
      expect(onFocus.mock.calls.length).toBe(1);
    });
  });
  describe("onBlur prop", function () {
    it("calls onBlur prop", function () {
      var onBlur = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        onBlur: onBlur
      }));
      wrapper.find("input").last().invoke("onBlur")({});
      expect(onBlur.mock.calls.length).toBe(1);
    });
  });
  describe("focusVisible state", function () {
    it("sets correct class name when focus event occurs", function () {
      var onFocus = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        onFocus: onFocus
      }));
      wrapper.find("input").last().invoke("onFocus")({});
      expect(wrapper.find("Input").childAt(0).childAt(0).hasClass("focusVisible")).toEqual(true);
    });
    it("sets correct class name when blur event occurs", function () {
      var onBlur = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Input["default"], {
        onBlur: onBlur
      }));
      wrapper.find("input").last().invoke("onFocus")({});
      wrapper.find("input").last().invoke("onBlur")();
      expect(wrapper.find("Input").childAt(0).childAt(0).hasClass("focusVisible")).toEqual(false);
    });
  });
});