"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _InputHint = _interopRequireDefault(require("./InputHint.jsx"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<InputHint>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputHint["default"], null));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputHint["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("children prop", function () {
    it("renders given children inside the Typography element", function () {
      var child = /*#__PURE__*/_react["default"].createElement("span", null, "hello");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputHint["default"], null, child));
      expect(wrapper.find("InputHint").find("Typography").contains(child)).toEqual(true);
    });
  });
  describe("color prop", function () {
    it("passes color prop through to Typography", function () {
      var color = "white";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputHint["default"], {
        color: color
      }));
      expect(wrapper.find("Typography").props().color).toEqual(color);
    });
  });
  describe("classes prop", function () {
    it("applies classes to the div inside of InputHint", function () {
      var classes = ["classOne"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputHint["default"], {
        classes: classes
      }));
      expect(wrapper.find("InputHint").childAt(0).find("div").hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClass decorator", function () {
      var classes = ["riipen", "riipen-inputhint"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputHint["default"], null));
      expect(wrapper.find("InputHint").props().classes.sort()).toEqual(classes.sort());
    });
    it("gives an error when classes are provided as one string", function () {
      var classes = "classOne classTwo";
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputHint["default"], {
        classes: classes
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
});