"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _InputLabel = _interopRequireDefault(require("./InputLabel.jsx"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<InputLabel>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputLabel["default"], null));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputLabel["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("children prop", function () {
    it("renders given children inside the label and Typography element", function () {
      var child = /*#__PURE__*/_react["default"].createElement("div", null, "it's a label");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputLabel["default"], null, child));
      expect(wrapper.find("InputLabel").find("label").find("Typography").contains(child)).toEqual(true);
    });
    it("does not render label element when children is not given", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputLabel["default"], null));
      expect(wrapper.find("InputLabel").find("label")).toHaveLength(0);
    });
  });
  describe("classes prop", function () {
    it("applies all classes to the label element when children is given", function () {
      var classes = ["classOne"];

      var child = /*#__PURE__*/_react["default"].createElement("div", null, "it's a label");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputLabel["default"], {
        classes: classes
      }, child));
      expect(wrapper.find("InputLabel").find("label").hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClass decorator", function () {
      var classes = ["riipen", "riipen-inputlabel"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputLabel["default"], null));
      expect(wrapper.find("InputLabel").props().classes.sort()).toEqual(classes.sort());
    });
    it("gives an error when classes are provided as one string", function () {
      var classes = "classOne classTwo";
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputLabel["default"], {
        classes: classes
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("color prop", function () {
    it("passes color prop through to Typography", function () {
      var color = "white";

      var child = /*#__PURE__*/_react["default"].createElement("div", null, "it's a label");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputLabel["default"], {
        color: color
      }, child));
      expect(wrapper.find("Typography").at(0).props().color).toEqual(color);
    });
    it("applies color class to the InputHint element with a valid color", function () {
      var color = "black";
      var hint = "hint";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputLabel["default"], {
        color: color,
        hint: hint
      }));
      expect(wrapper.find("InputHint").props().color).toEqual(color);
    });
  });
  describe("hint prop", function () {
    it("displays given hint node inside the InputHint element", function () {
      var hint = /*#__PURE__*/_react["default"].createElement("span", null, "it's a hint");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputLabel["default"], {
        hint: hint
      }));
      expect(wrapper.find("InputLabel").find("InputHint").contains(hint)).toEqual(true);
    });
    it("does not render InputHint element when hint is not given", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputLabel["default"], null));
      expect(wrapper.find("InputLabel").find("InputHint")).toHaveLength(0);
    });
  });
  describe("required prop", function () {
    it("displays an asterisk at the end of the label when required is true", function () {
      var child = /*#__PURE__*/_react["default"].createElement("div", null, "it's a label");

      var required = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputLabel["default"], {
        required: required
      }, child));
      expect(wrapper.find("InputLabel").find("label").text().substr(-1)).toEqual("*");
    });
    it("does not display an asterisk when required is false", function () {
      var child = /*#__PURE__*/_react["default"].createElement("div", null, "it's a label");

      var required = false;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputLabel["default"], {
        required: required
      }, child));
      expect(wrapper.find("InputLabel").find("label").text().substr(-1)).not.toEqual("*");
    });
  });
  describe("suffix prop", function () {
    it("renders suffix inside the label and Typography element", function () {
      var suffix = /*#__PURE__*/_react["default"].createElement("span", null, "Test");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputLabel["default"], null, suffix));
      expect(wrapper.find("InputLabel").find("label").find("Typography").contains(suffix)).toEqual(true);
    });
  });
  describe("fontWeight prop", function () {
    it("Passes fontWeight to the underlying typography", function () {
      var fontWeight = "bold";

      var child = /*#__PURE__*/_react["default"].createElement("div", null, "it's a label");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputLabel["default"], {
        fontWeight: fontWeight
      }, child));
      expect(wrapper.find("Typography").at(0).props().fontWeight).toEqual(fontWeight);
    });
  });
  describe("variant prop", function () {
    it("Passes variant to the underlying typography", function () {
      var variant = "h4";

      var child = /*#__PURE__*/_react["default"].createElement("div", null, "it's a label");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_InputLabel["default"], {
        variant: variant
      }, child));
      expect(wrapper.find("Typography").at(0).props().variant).toEqual(variant);
    });
  });
});