"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _Link = _interopRequireDefault(require("./Link.jsx"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Link>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Link["default"], {
        href: "google.com"
      }, /*#__PURE__*/_react["default"].createElement("span", null, "link")));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Link["default"], {
      href: "google.com"
    }, /*#__PURE__*/_react["default"].createElement("span", null, "link")));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Link["default"], {
        href: "google.com"
      }, /*#__PURE__*/_react["default"].createElement("span", null, "link")));
      var component = wrapper.find("Link");
      expect(component.props().classes).toEqual([]);
      expect(component.props().color).toEqual("primary");
      expect(component.props().component).toEqual("a");
      expect(component.props().underline).toEqual("none");
    });
  });
  describe("children prop", function () {
    it("renders given children", function () {
      var child = /*#__PURE__*/_react["default"].createElement("span", null, "link");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Link["default"], {
        href: "google.com"
      }, child));
      expect(wrapper.find("Link").contains(child)).toEqual(true);
    });
  });
  describe("classes prop", function () {
    it("sets custom class", function () {
      var classes = ["classOne"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Link["default"], {
        classes: classes,
        href: "google.com"
      }, /*#__PURE__*/_react["default"].createElement("span", null, "link")));
      expect(wrapper.find("Link").childAt(0).hasClass(classes[0])).toEqual(true);
    });
  });
  describe("color prop", function () {
    it("applies valid custom color class", function () {
      var color = "negative";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Link["default"], {
        color: color,
        href: "google.com"
      }, /*#__PURE__*/_react["default"].createElement("span", null, "link")));
      expect(wrapper.find("Link").childAt(0).hasClass(color)).toEqual(true);
    });
    it("gives an error when given an invalid color", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Link["default"], {
        color: "pink",
        href: "google.com"
      }, /*#__PURE__*/_react["default"].createElement("span", null, "link")));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("component prop", function () {
    it("sets custom component", function () {
      var component = "div";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Link["default"], {
        component: component,
        href: "google.com"
      }, /*#__PURE__*/_react["default"].createElement("span", null, "link")));
      expect(wrapper.find("Link").childAt(0).name()).toEqual(component);
    });
    it("gives an error when given an invalid component", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var component = "abcd";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Link["default"], {
        component: component,
        href: "google.com"
      }, /*#__PURE__*/_react["default"].createElement("span", null, "link")));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("focusVisible state", function () {
    it("applies focusVisible class when focus event occurs", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Link["default"], {
        href: "google.com"
      }, /*#__PURE__*/_react["default"].createElement("span", null, "link")));
      wrapper.find("a").invoke("onFocus")({});
      expect(wrapper.find("Link").childAt(0).hasClass("focusVisible")).toEqual(true);
    });
    it("does not apply focusVisible class when blur event occurs", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Link["default"], {
        href: "google.com"
      }, /*#__PURE__*/_react["default"].createElement("span", null, "link")));
      wrapper.find("a").invoke("onFocus")({});
      wrapper.find("a").invoke("onBlur")();
      expect(wrapper.find("Link").childAt(0).hasClass("focusVisible")).toEqual(false);
    });
  });
});