"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _List = _interopRequireDefault(require("./List"));

var _ListItem = _interopRequireDefault(require("./ListItem"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<List>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_List["default"], null));
    } catch (theError) {
      error = theError;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_List["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("children prop", function () {
    it("displays given children", function () {
      var child = /*#__PURE__*/_react["default"].createElement("div", null, "child");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_List["default"], null, child));
      expect(wrapper.containsMatchingElement(child)).toBeTruthy();
    });
  });
  describe("classes prop", function () {
    it("sets custom class", function () {
      var classes = ["newClass"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_List["default"], {
        classes: classes
      }));
      expect(wrapper.find("List").childAt(0).hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClass decorator", function () {
      var classes = ["riipen", "riipen-list"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_List["default"], null));
      expect(wrapper.find("List").props().classes).toEqual(classes.sort());
    });
  });
  describe("spacing prop", function () {
    it("passes spacing prop into children nodes", function () {
      var spacing = 3;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_List["default"], {
        spacing: spacing
      }, /*#__PURE__*/_react["default"].createElement(_ListItem["default"], null, "one")));
      expect(wrapper.find("ListItem").props().spacing).toEqual(spacing);
    });
  });
  describe("variant prop", function () {
    it("passes variant prop into children nodes", function () {
      var variant = "horizontal";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_List["default"], {
        variant: variant
      }, /*#__PURE__*/_react["default"].createElement(_ListItem["default"], null, "one")));
      expect(wrapper.find("ListItem").props().variant).toEqual(variant);
    });
  });
});