"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _default = _interopRequireDefault(require("../themes/default"));

var _ListItem = _interopRequireDefault(require("./ListItem"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<ListItem>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ListItem["default"], null));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ListItem["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ListItem["default"], null));
      var component = wrapper.find("ListItem");
      expect(component.props().classes).toEqual(["riipen", "riipen-listitem"]);
      expect(component.props().spacing).toEqual(2);
      expect(component.props().variant).toEqual("vertical");
    });
  });
  describe("children prop", function () {
    it("renders given children", function () {
      var child = /*#__PURE__*/_react["default"].createElement("div", null, "childreeennn");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ListItem["default"], null, child));
      expect(wrapper.find("ListItem").childAt(0).contains(child)).toEqual(true);
    });
  });
  describe("classes prop", function () {
    it("applies given classes", function () {
      var classes = ["classOne"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ListItem["default"], {
        classes: classes
      }));
      expect(wrapper.find("ListItem").childAt(0).hasClass(classes[0])).toEqual(true);
    });
  });
  describe("spacing prop", function () {
    it("applies custom spacing", function () {
      var spacing = 5;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ListItem["default"], {
        spacing: spacing
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain(_default["default"].spacing(spacing));
    });
  });
  describe("variant prop", function () {
    it("sets variant class name with valid custom variant", function () {
      var variant = "horizontal";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ListItem["default"], {
        variant: variant
      }));
      expect(wrapper.find("ListItem").childAt(0).hasClass(variant)).toEqual(true);
    });
    it("throws an error with with invalid variant", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ListItem["default"], {
        variant: "star"
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
});