"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _testUtils = _interopRequireDefault(require("react-dom/test-utils"));

var _Menu = _interopRequireDefault(require("./Menu"));

var _MenuItem = _interopRequireDefault(require("./MenuItem"));

var _AppBar = _interopRequireDefault(require("./AppBar"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Menu>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Menu["default"], null));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Menu["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Menu["default"], null));
      expect(wrapper.find("Menu").props().closeOnSelect).toEqual(true);
      expect(wrapper.find("Menu").props().isOpen).toEqual(true);
      expect(wrapper.find("Menu").props().keepOnScreen).toEqual(false);
      expect(wrapper.find("Menu").props().popoverStyles).toEqual({});
    });
  });
  describe("anchorEl prop", function () {
    it("passes anchorEl prop to correct child", function () {
      var anchorEl = _testUtils["default"].renderIntoDocument( /*#__PURE__*/_react["default"].createElement(_AppBar["default"], null));

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Menu["default"], {
        anchorEl: anchorEl
      }));
      expect(wrapper.find("Popover").props().anchorEl).toEqual(anchorEl);
    });
  });
  describe("anchorPosition prop", function () {
    it("passes anchorPosition prop to correct child", function () {
      var anchorPosition = {
        horizontal: "left",
        vertical: "bottom"
      };
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Menu["default"], {
        anchorPosition: anchorPosition
      }));
      expect(wrapper.find("Popover").props().anchorPosition).toEqual(anchorPosition);
    });
  });
  describe("children prop", function () {
    it("renders given children", function () {
      var child = /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null, "child");

      var anchorEl = _testUtils["default"].renderIntoDocument( /*#__PURE__*/_react["default"].createElement("div", null, /*#__PURE__*/_react["default"].createElement(_AppBar["default"], null)));

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Menu["default"], {
        anchorEl: anchorEl
      }, child));
      expect(wrapper.containsMatchingElement(child)).toBeTruthy();
    });
  });
  describe("classes prop", function () {
    it("sets custom class", function () {
      var classes = ["newClass"];

      var anchorEl = _testUtils["default"].renderIntoDocument( /*#__PURE__*/_react["default"].createElement("div", null, /*#__PURE__*/_react["default"].createElement(_AppBar["default"], null)));

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Menu["default"], {
        anchorEl: anchorEl,
        classes: classes
      }, /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null)));
      expect(wrapper.find("MenuList").childAt(0).hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClasses decorator", function () {
      var classes = ["riipen", "riipen-menu"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Menu["default"], null));
      expect(wrapper.find("Menu").props().classes.sort()).toEqual(classes.sort());
    });
  });
  describe("closeOnSelect prop", function () {
    it("does not invoke onClose when closeOnSelect is false", function () {
      var closeOnSelect = false;
      var onClose = jest.fn();

      var anchorEl = _testUtils["default"].renderIntoDocument( /*#__PURE__*/_react["default"].createElement("div", null, /*#__PURE__*/_react["default"].createElement(_AppBar["default"], null)));

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Menu["default"], {
        anchorEl: anchorEl,
        closeOnSelect: closeOnSelect,
        onClose: onClose
      }, /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null)));
      wrapper.find("MenuItem").childAt(0).invoke("onClick")();
      expect(onClose).toHaveBeenCalledTimes(0);
    });
  });
  describe("contentPosition prop", function () {
    it("passes contentPosition prop to correct child", function () {
      var contentPosition = {
        horizontal: "left",
        vertical: "bottom"
      };
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Menu["default"], {
        contentPosition: contentPosition
      }));
      expect(wrapper.find("Popover").props().contentPosition).toEqual(contentPosition);
    });
  });
  describe("fullWidth prop", function () {
    it("passes fullWidth prop to correct child", function () {
      var fullWidth = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Menu["default"], {
        fullWidth: fullWidth
      }));
      expect(wrapper.find("Popover").props().fullWidth).toEqual(fullWidth);
    });
  });
  describe("isOpen prop", function () {
    it("passes isOpen prop to correct child", function () {
      var isOpen = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Menu["default"], {
        isOpen: isOpen
      }));
      expect(wrapper.find("Popover").props().isOpen).toEqual(isOpen);
    });
  });
  describe("keepOnScreen prop", function () {
    it("passes keepOnScreen prop to correct child", function () {
      var keepOnScreen = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Menu["default"], {
        keepOnScreen: keepOnScreen
      }));
      expect(wrapper.find("Popover").props().keepOnScreen).toEqual(keepOnScreen);
    });
  });
  describe("marginThreshold prop", function () {
    it("passes marginThreshold prop to correct child", function () {
      var marginThreshold = 2;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Menu["default"], {
        marginThreshold: marginThreshold
      }));
      expect(wrapper.find("Popover").props().marginThreshold).toEqual(marginThreshold);
    });
  });
  describe("onClose prop", function () {
    it("invokes onClose when child is clicked with closeOnSelect", function () {
      var closeOnSelect = true;
      var onClose = jest.fn();

      var anchorEl = _testUtils["default"].renderIntoDocument( /*#__PURE__*/_react["default"].createElement("div", null, /*#__PURE__*/_react["default"].createElement(_AppBar["default"], null)));

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Menu["default"], {
        anchorEl: anchorEl,
        closeOnSelect: closeOnSelect,
        onClose: onClose
      }, /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null)));
      wrapper.find("MenuItem").find("div").invoke("onClick")();
      expect(onClose).toHaveBeenCalledTimes(1);
    });
    it("does not invoke onClose when event type is not a click event", function () {
      var onClose = jest.fn();

      var anchorEl = _testUtils["default"].renderIntoDocument( /*#__PURE__*/_react["default"].createElement("div", null, /*#__PURE__*/_react["default"].createElement(_AppBar["default"], null)));

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Menu["default"], {
        anchorEl: anchorEl,
        onClose: onClose
      }, /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], {
        onSubmit: jest.fn()
      })));
      wrapper.find("MenuItem").childAt(0).invoke("onSubmit")();
      expect(onClose).toHaveBeenCalledTimes(0);
    });
  });
  describe("onSelect prop", function () {
    it("invokes onSelect when child is clicked", function () {
      var event = {};
      var onSelect = jest.fn();

      var anchorEl = _testUtils["default"].renderIntoDocument( /*#__PURE__*/_react["default"].createElement("div", null, /*#__PURE__*/_react["default"].createElement(_AppBar["default"], null)));

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Menu["default"], {
        anchorEl: anchorEl,
        onSelect: onSelect
      }, /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null)));
      wrapper.find("MenuItem").childAt(0).invoke("onClick")(event);
      expect(onSelect).toHaveBeenCalledWith(0, event);
    });
  });
  describe("popoverStyles prop", function () {
    it("passes popoverStyles prop to correct child", function () {
      var styles = _testUtils["default"].renderIntoDocument( /*#__PURE__*/_react["default"].createElement("style", null));

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Menu["default"], {
        popoverStyles: styles
      }));
      expect(wrapper.find("Popover").props().styles).toEqual(styles);
    });
  });
  describe("selectedIndex prop", function () {
    it("passes selectedIndex prop to correct child", function () {
      var selectedIndex = 0;

      var anchorEl = _testUtils["default"].renderIntoDocument( /*#__PURE__*/_react["default"].createElement("div", null, /*#__PURE__*/_react["default"].createElement(_AppBar["default"], null)));

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Menu["default"], {
        anchorEl: anchorEl,
        selectedIndex: selectedIndex
      }, /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null)));
      expect(wrapper.find("MenuList").props().selectedIndex).toEqual(selectedIndex);
    });
  });
});