"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _MenuItem = _interopRequireDefault(require("./MenuItem.jsx"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<MenuItem>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null));
      var component = wrapper.find("MenuItem");
      expect(component.props().classes).toEqual(["riipen", "riipen-menuitem"]);
    });
  });
  describe("children prop", function () {
    it("render given children", function () {
      var child = /*#__PURE__*/_react["default"].createElement("div", null, "hello hello");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null, child));
      expect(wrapper.find("MenuItem").childAt(0).contains(child)).toEqual(true);
    });
  });
  describe("classes prop", function () {
    it("passes given classes into classes prop of ListItem", function () {
      var classes = ["classOne"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], {
        classes: classes
      }));
      expect(wrapper.find("MenuItem").childAt(0).hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClass decorator", function () {
      var classes = ["riipen", "riipen-menuitem"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null));
      expect(wrapper.find("MenuItem").props().classes.sort()).toEqual(classes.sort());
    });
    it("gives an error when classes are provided as one string", function () {
      var classes = "classOne classTwo";
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], {
        classes: classes
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("color prop", function () {
    it("sets color class name with valid custom color", function () {
      var color = "primary";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], {
        color: color
      }));
      expect(wrapper.find("MenuItem").childAt(0).hasClass(color)).toEqual(true);
    });
    it("throws an error with with invalid color", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], {
        color: "star"
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("disabled prop", function () {
    it("sets disabled class name with valid custom disabled", function () {
      var disabled = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], {
        disabled: disabled
      }));
      expect(wrapper.find("MenuItem").childAt(0).hasClass("disabled")).toEqual(true);
    });
  });
  describe("onSelect prop", function () {
    it("invokes onSelect handler when ListItem is clicked", function () {
      var handler = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], {
        onSelect: handler
      }));
      wrapper.find("MenuItem").childAt(0).invoke("onClick")();
      expect(handler).toHaveBeenCalledTimes(1);
    });
    it("does not invoke onSelect handler when ListItem is clicked and disabled prop is true", function () {
      var disabled = true;
      var handler = jest.fn();
      var event = {
        stopPropagation: jest.fn(0)
      };
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], {
        disabled: disabled,
        onSelect: handler
      }));
      wrapper.find("MenuItem").childAt(0).invoke("onClick")(event);
      expect(handler).not.toHaveBeenCalled();
      expect(event.stopPropagation).toHaveBeenCalledTimes(1);
    });
    it("invokes onSelect handler when ListItem is clicked and disabled prop is false", function () {
      var disabled = false;
      var handler = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], {
        disabled: disabled,
        onSelect: handler
      }));
      wrapper.find("MenuItem").childAt(0).invoke("onClick")();
      expect(handler).toHaveBeenCalledTimes(1);
    });
  });
  describe("selected prop", function () {
    it("applies seleted class when selected prop is true", function () {
      var selected = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], {
        selected: selected
      }));
      expect(wrapper.find("MenuItem").childAt(0).hasClass("selected")).toEqual(true);
    });
    it("does not apply selected class when selected prop is false", function () {
      var selected = false;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], {
        selected: selected
      }));
      expect(wrapper.find("MenuItem").childAt(0).hasClass("selected")).toEqual(false);
    });
  });
});