"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _MenuItem = _interopRequireDefault(require("./MenuItem"));

var _MenuList = _interopRequireDefault(require("./MenuList"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<MenuList>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuList["default"], null, /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null)));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuList["default"], null, /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null)));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuList["default"], null, /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null)));
      var component = wrapper.find("MenuList");
      expect(component.props().selectedIndex).toEqual(-1);
    });
  });
  describe("children prop", function () {
    it("displays given non null children", function () {
      var child = /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null, "one");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuList["default"], null, null, child));
      var childrenNodes = wrapper.find("MenuList").childAt(0).children();
      expect(childrenNodes.containsMatchingElement(child)).toEqual(true);
      expect(childrenNodes).toHaveLength(1);
    });
    it("invokes onSelect when child clicked", function () {
      var onSelect = jest.fn();
      var event = {};
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuList["default"], {
        onSelect: onSelect,
        variant: "selection"
      }, /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], {
        disabled: false
      }), /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null)));
      wrapper.find("MenuItem").at(0).find("div").invoke("onClick")(event);
      expect(onSelect).toHaveBeenCalledWith(0, event);
    });
  });
  describe("classes prop", function () {
    it("applies custom classes", function () {
      var classes = ["classOne"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuList["default"], {
        classes: classes
      }, /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null)));
      expect(wrapper.find("MenuList").childAt(0).hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClass decorator", function () {
      var classes = ["riipen", "riipen-menulist"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuList["default"], null, /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null)));
      expect(wrapper.find("MenuList").props().classes.sort()).toEqual(classes.sort());
    });
  });
  describe("color prop", function () {
    it("passes color prop into children nodes", function () {
      var color = "secondary";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuList["default"], {
        color: color
      }, /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null, "one")));
      expect(wrapper.find("MenuItem").props().color).toEqual(color);
    });
    it("gives an error with invalid color", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuList["default"], {
        color: "pink"
      }, /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null)));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("onSelect prop", function () {
    it("invokes onSelect with a null idx when div is clicked", function () {
      var onSelect = jest.fn();
      var event = {};
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuList["default"], {
        onSelect: onSelect
      }, /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null, "one")));
      wrapper.find("MenuItem").at(0).find("div").invoke("onClick")(event);
      expect(onSelect).toHaveBeenLastCalledWith(0, event);
    });
  });
  describe("selectedIndex prop", function () {
    it("selects children node at given index", function () {
      var selectedIndex = 1;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuList["default"], {
        selectedIndex: selectedIndex
      }, /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null, "one"), /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null, "two")));
      expect(wrapper.find("MenuItem").at(selectedIndex).props().selected).toEqual(true);
    });
    it("does not select children nodes not at given index", function () {
      var selectedIndex = 1;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_MenuList["default"], {
        selectedIndex: selectedIndex
      }, /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null, "one"), /*#__PURE__*/_react["default"].createElement(_MenuItem["default"], null, "two")));
      expect(wrapper.find("MenuItem").at(0).props().selected).toEqual(false);
    });
  });
});