"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _NoSSR = _interopRequireDefault(require("./NoSSR.jsx"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<NoSSR>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_NoSSR["default"], null));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_NoSSR["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default prop", function () {
    it("sets correct default props", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_NoSSR["default"], null));
      var component = wrapper.find("NoSSR");
      expect(component.props().fallback).toEqual(null);
    });
  });
  describe("children prop", function () {
    it("renders given children", function () {
      var child = /*#__PURE__*/_react["default"].createElement("span", null, "pizzas");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_NoSSR["default"], null, child));
      expect(wrapper.contains(child)).toEqual(true);
    });
    it("renders children over fallback when mounted", function () {
      var child = /*#__PURE__*/_react["default"].createElement("span", null, "pizzas");

      var fallback = /*#__PURE__*/_react["default"].createElement("span", null, "fallback");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_NoSSR["default"], {
        fallback: fallback
      }, child));
      wrapper.setState({
        mounted: true
      });
      expect(wrapper.contains(child)).toEqual(true);
      expect(wrapper.contains(fallback)).toEqual(false);
    });
  });
  describe("fallback prop", function () {
    it("renders fallback over children when mounted is false", function () {
      var child = /*#__PURE__*/_react["default"].createElement("span", null, "pizzas");

      var fallback = /*#__PURE__*/_react["default"].createElement("span", null, "fallback");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_NoSSR["default"], {
        fallback: fallback
      }, child));
      wrapper.setState({
        mounted: false
      });
      expect(wrapper.contains(child)).toEqual(false);
      expect(wrapper.contains(fallback)).toEqual(true);
    });
  });
});