"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _default = _interopRequireDefault(require("../themes/default"));

var _Paper = _interopRequireDefault(require("./Paper"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Paper>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Paper["default"], null));
    } catch (theError) {
      error = theError;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Paper["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Paper["default"], null));
      expect(wrapper.find("Paper").props().component).toEqual("div");
      expect(wrapper.find("Paper").props().rounded).toEqual(false);
      expect(wrapper.find("Paper").props().variant).toEqual("elevation");
    });
  });
  describe("children prop", function () {
    it("displays given children", function () {
      var child = /*#__PURE__*/_react["default"].createElement("div", null, "child");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Paper["default"], null, child));
      expect(wrapper.containsMatchingElement(child)).toBeTruthy();
    });
  });
  describe("classes prop", function () {
    it("sets custom class", function () {
      var classes = ["newClass"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Paper["default"], {
        classes: classes
      }));
      expect(wrapper.find("Paper").childAt(0).hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClasses decorator", function () {
      var classes = ["riipen", "riipen-paper"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Paper["default"], null));
      expect(wrapper.find("Paper").props().classes.sort()).toEqual(classes.sort());
    });
  });
  describe("component prop", function () {
    it("sets custom component", function () {
      var component = "span";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Paper["default"], {
        component: component
      }));
      expect(wrapper.find("Paper").childAt(0).name()).toEqual(component);
    });
    it("gives an error when given an invalid component", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var component = "abcd";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Paper["default"], {
        component: component
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("elevation prop", function () {
    it("sets elevation box shadow height for the component", function () {
      var elevation = 3;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Paper["default"], {
        elevation: elevation
      }));
      expect(wrapper.find("Paper").find("JSXStyle").props().dynamic).toContain(_default["default"].shadows[elevation]);
    });
  });
  describe("padding prop", function () {
    it("sets padding for the component", function () {
      var padding = 3;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Paper["default"], {
        padding: padding
      }));
      expect(wrapper.find("Paper").find("JSXStyle").props().dynamic).toContain(_default["default"].spacing[padding]);
    });
  });
  describe("rounded prop", function () {
    it("sets class name as rounded when rounded is true", function () {
      var rounded = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Paper["default"], {
        rounded: rounded
      }));
      expect(wrapper.find("Paper").childAt(0).hasClass("rounded")).toEqual(true);
    });
  });
  describe("variant prop", function () {
    it("sets class name as elevation by default", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Paper["default"], null));
      expect(wrapper.find("Paper").childAt(0).hasClass("elevation")).toEqual(true);
    });
    it("sets class name as outlined for outlined variant", function () {
      var variant = "outlined";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Paper["default"], {
        variant: variant
      }));
      expect(wrapper.find("Paper").childAt(0).hasClass("outlined")).toEqual(true);
    });
    it("gives an error when given an invalid variant", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var variant = "default";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Paper["default"], {
        variant: variant
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
});