"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _testUtils = _interopRequireDefault(require("react-dom/test-utils"));

var _Popover = _interopRequireDefault(require("./Popover"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr && (typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]); if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

describe("<Popover>", function () {
  var props;
  beforeEach(function () {
    props = {
      anchorEl: _testUtils["default"].renderIntoDocument( /*#__PURE__*/_react["default"].createElement("div", null))
    };
  });
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Popover["default"], props));
    } catch (theError) {
      error = theError;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Popover["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("anchorEl prop", function () {
    it("does not render children when no anchorEl", function () {
      props.anchorEl = null;
      props.children = "a child";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Popover["default"], props));
      expect(wrapper.text()).not.toContain(props.children);
    });
  });
  describe("children prop", function () {
    it("renders children when popover is open and anchorEl exists", function () {
      props.children = "a child";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Popover["default"], props));
      expect(wrapper.text()).toContain(props.children);
    });
  });
  describe("classes prop", function () {
    it("applies classes to the root node of Popover", function () {
      props.classes = ["classOne"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Popover["default"], props));
      expect(wrapper.find("Popover").childAt(0).hasClass(props.classes[0])).toEqual(true);
    });
    it("gives an error when classes are provided as one string", function () {
      props.classes = "classOne classTwo";
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Popover["default"], props));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("closeOnScrolled prop", function () {
    [["resize", true], ["scroll", true], ["resize", false], ["scroll", false]].forEach(function (_ref) {
      var _ref2 = _slicedToArray(_ref, 2),
          event = _ref2[0],
          closeOnScrolled = _ref2[1];

      it("".concat(closeOnScrolled ? "closes" : "does not close", " Popover on ").concat(event, " event when closeOnScrolled is ").concat(closeOnScrolled), function () {
        var anchorElEvents = {};
        props.anchorEl.addEventListener = jest.fn(function (anchorElEvent, callback) {
          anchorElEvents[anchorElEvent] = callback;
        });
        props.closeOnScrolled = closeOnScrolled;
        props.onClose = jest.fn();
        (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Popover["default"], props));
        anchorElEvents[event]({
          type: event
        });
        expect(props.onClose).toHaveBeenCalledTimes(closeOnScrolled ? 1 : 0);
      });
    });
  });
  describe("component prop", function () {
    it("renders span component as default", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Popover["default"], props));
      expect(wrapper.find("Popover").childAt(0).name()).toBe("span");
    });
    it("renders custom component", function () {
      props.component = "div";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Popover["default"], props));
      expect(wrapper.find("Popover").childAt(0).name()).toBe(props.component);
    });
  });
  describe("fullWidth prop", function () {
    it("sets left to 0px when fullWidth is true", function () {
      props.fullWidth = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Popover["default"], props));
      expect(wrapper.find("Popover").childAt(0).props().style.left).toEqual("0px");
    });
  });
  describe("isOpen prop", function () {
    it("passes open class to component", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Popover["default"], props));
      expect(wrapper.find("Popover").childAt(0).hasClass("open")).toBe(true);
    });
    it("does not pass open class to component when isOpen is false", function () {
      props.isOpen = false;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Popover["default"], props));
      expect(wrapper.find("Popover").childAt(0).hasClass("open")).toBe(false);
    });
    it("does not render children when isOpen is false", function () {
      props.children = "a child";
      props.isOpen = false;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Popover["default"], props));
      expect(wrapper.text()).not.toContain(props.children);
    });
  });
  describe("lockScroll prop", function () {
    it("locks scroll of the parent element when lockScroll is true", function () {
      document.body.style.overflow = "scroll";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Popover["default"], props));
      expect(document.body.style.overflow).toEqual("hidden");
    });
    it("locks scroll of the parent element when lockScroll is false", function () {
      document.body.style.overflow = "scroll";
      props.lockScroll = false;
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Popover["default"], props));
      expect(document.body.style.overflow).toEqual("scroll");
    });
  });
  describe("onClose prop", function () {
    it("calls onClose on mousedown event", function () {
      var events = {};
      window.addEventListener = jest.fn(function (event, callback) {
        events[event] = callback;
      });
      props.onClose = jest.fn();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Popover["default"], props));
      events.keydown({
        target: _testUtils["default"].renderIntoDocument( /*#__PURE__*/_react["default"].createElement("div", null)),
        type: "mousedown"
      });
      expect(props.onClose).toHaveBeenCalledTimes(1);
    });
    it("calls onClose on escape keydown event", function () {
      var events = {};
      window.addEventListener = jest.fn(function (event, callback) {
        events[event] = callback;
      });
      props.onClose = jest.fn();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Popover["default"], props));
      events.keydown({
        key: "Escape",
        type: "keydown"
      });
      expect(props.onClose).toHaveBeenCalledTimes(1);
    });
    it("does not call onClose if mousedown event is on anchorEl", function () {
      var events = {};
      window.addEventListener = jest.fn(function (event, callback) {
        events[event] = callback;
      });
      props.onClose = jest.fn();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Popover["default"], props));
      events.keydown({
        target: props.anchorEl,
        type: "mousedown"
      });
      expect(props.onClose).not.toHaveBeenCalled();
    });
  });
  describe("onKeyDown prop", function () {
    it("calls onKeyDown on key down event", function () {
      var events = {};
      window.addEventListener = jest.fn(function (event, callback) {
        events[event] = callback;
      });
      props.onKeyDown = jest.fn();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Popover["default"], props));
      events.keydown({
        key: "Enter",
        stopImmediatePropagation: jest.fn(),
        type: "keydown"
      });
      expect(props.onKeyDown).toHaveBeenCalledTimes(1);
    });
  });
  describe("styles prop", function () {
    it("passes styles to component", function () {
      props.styles = {
        color: "pink"
      };
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Popover["default"], props));
      expect(wrapper.find("Popover").childAt(0).props().style.color).toEqual(props.styles.color);
    });
  });
});