"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _ProgressBar = _interopRequireDefault(require("./ProgressBar.jsx"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<ProgressBar>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ProgressBar["default"], null));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ProgressBar["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var defaultProps = new _ProgressBar["default"]().type.defaultProps;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ProgressBar["default"], null));
      var component = wrapper.find("ProgressBar");
      expect(component.props().color).toEqual(defaultProps.color);
      expect(component.props().completion).toEqual(defaultProps.completion);
      expect(component.props().unfilled).toEqual(defaultProps.unfilled);
    });
  });
  describe("classes prop", function () {
    it("applies all classes to the progress element", function () {
      var classes = ["classOne"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ProgressBar["default"], {
        classes: classes
      }));
      expect(wrapper.find("ProgressBar").find("progress").hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClass decorator", function () {
      var classes = ["riipen", "riipen-progressbar"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ProgressBar["default"], null));
      expect(wrapper.find("ProgressBar").props().classes.sort()).toEqual(classes.sort());
    });
    it("gives an error when classes are provided as one string", function () {
      var classes = "classOne classTwo";
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ProgressBar["default"], {
        classes: classes
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("color prop", function () {
    it("applies valid custom colour class to the progress element", function () {
      var color = "secondary";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ProgressBar["default"], {
        color: color
      }));
      expect(wrapper.find("ProgressBar").find("progress").hasClass(color)).toEqual(true);
    });
    it("gives an error with invalid color", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ProgressBar["default"], {
        color: "yellow"
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("unfilled prop", function () {
    it("applies valid custom unfilled class to the progress element", function () {
      var unfilled = "dark";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ProgressBar["default"], {
        unfilled: unfilled
      }));
      expect(wrapper.find("ProgressBar").find("progress").hasClass(unfilled)).toEqual(true);
    });
    it("gives an error with invalid unfilled value", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ProgressBar["default"], {
        color: "white"
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("completion prop", function () {
    it("passes given completion value into the progress element", function () {
      var completion = 0.5;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_ProgressBar["default"], {
        completion: completion
      }));
      expect(wrapper.find("ProgressBar").find("progress").props().value).toEqual(completion);
    });
  });
});