"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _Radio = _interopRequireDefault(require("./Radio"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Radio>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Radio["default"], {
        readOnly: true
      }));
    } catch (theError) {
      error = theError;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Radio["default"], {
      readOnly: true
    }));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var defaultProps = new _Radio["default"]().type.defaultProps;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Radio["default"], {
        readOnly: true
      }));
      expect(wrapper.find("Radio").props().checked).toEqual(defaultProps.checked);
      expect(wrapper.find("Radio").props().disabled).toEqual(defaultProps.disabled);
    });
  });
  describe("checked prop", function () {
    it("sets valid custom checked", function () {
      var checked = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Radio["default"], {
        checked: checked,
        readOnly: true
      }));
      expect(wrapper.find("Radio").find("input").props().checked).toEqual(checked);
    });
  });
  describe("classes prop", function () {
    it("sets custom class", function () {
      var classes = ["newClass"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Radio["default"], {
        classes: classes,
        readOnly: true
      }));
      expect(wrapper.find("Radio").childAt(0).hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClass decorator", function () {
      var classes = ["riipen", "riipen-radio"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Radio["default"], {
        readOnly: true
      }));
      expect(wrapper.find("Radio").props().classes).toEqual(classes.sort());
    });
  });
  describe("color prop", function () {
    it("sets valid custom  color", function () {
      var color = "default";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Radio["default"], {
        color: color,
        readOnly: true
      }));
      expect(wrapper.find("Radio").find("Typography").childAt(0).hasClass(color)).toBeTruthy();
    });
    it("gives an error when given an invalid color", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var color = "purple";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Radio["default"], {
        color: color,
        readOnly: true
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("disabled prop", function () {
    it("renders radio as disabled when disabled prop is true", function () {
      var disabled = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Radio["default"], {
        disabled: disabled,
        readOnly: true
      }));
      expect(wrapper.find("Radio").find("span").hasClass("disabled")).toBeTruthy();
    });
    it("renders radio with color when disabled prop is false", function () {
      var color = "primary";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Radio["default"], {
        color: color,
        readOnly: true
      }));
      expect(wrapper.find("Radio").find("span").hasClass(color)).toBeTruthy();
      expect(wrapper.find("Radio").find("span").hasClass("disabled")).toBeFalsy();
    });
  });
  describe("label prop", function () {
    it("renders custom label", function () {
      var label = "Pizza";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Radio["default"], {
        label: label,
        readOnly: true
      }));
      expect(wrapper.find("Radio").find("label").text()).toEqual(label);
    });
  });
});