"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _freeSolidSvgIcons = require("@fortawesome/free-solid-svg-icons");

var _reactFontawesome = require("@fortawesome/react-fontawesome");

var _RadioButton = _interopRequireDefault(require("./RadioButton"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<RadioButton>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], null));
    } catch (theError) {
      error = theError;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("checked prop", function () {
    it("sets RadioButton element class name as checked when checked is true", function () {
      var checked = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        checked: checked,
        readOnly: true
      }));
      expect(wrapper.find("RadioButton").childAt(0).hasClass("checked")).toEqual(true);
    });
    it("sets label element class name as checked when checked is true", function () {
      var checked = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        checked: checked,
        readOnly: true
      }));
      expect(wrapper.find("label").hasClass("checked")).toEqual(true);
    });
    it("sets input element class name as checked when checked is true", function () {
      var checked = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        checked: checked,
        readOnly: true
      }));
      expect(wrapper.find("input").props().checked).toEqual(checked);
    });
  });
  describe("classes prop", function () {
    it("sets custom class", function () {
      var classes = ["newClass"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        classes: classes
      }));
      expect(wrapper.find("RadioButton").childAt(0).hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClasses decorator", function () {
      var classes = ["riipen", "riipen-radiobutton"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], null));
      expect(wrapper.find("RadioButton").props().classes.sort()).toEqual(classes.sort());
    });
  });
  describe("color prop", function () {
    it("sets the color class", function () {
      var color = "primary";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        color: color
      }));
      expect(wrapper.find("RadioButton").childAt(0).hasClass(color)).toEqual(true);
    });
  });
  describe("disabled prop", function () {
    it("sets RadioButton element class name as disabled when disabled is true", function () {
      var disabled = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        disabled: disabled,
        readOnly: true
      }));
      expect(wrapper.find("RadioButton").childAt(0).hasClass("disabled")).toEqual(true);
    });
    it("sets label element class name as disabled when disabled is true", function () {
      var disabled = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        disabled: disabled,
        readOnly: true
      }));
      expect(wrapper.find("label").hasClass("disabled")).toEqual(true);
    });
  });
  it("sets custom disabled for input element", function () {
    var disabled = true;
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
      disabled: disabled,
      readOnly: true
    }));
    expect(wrapper.find("input").props().disabled).toEqual(disabled);
  });
  describe("label prop", function () {
    it("sets custom label", function () {
      var label = "Test";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        label: label,
        readOnly: true
      }));
      expect(wrapper.text()).toEqual(label);
      expect(wrapper.find(".content").children().contains(label)).toEqual(true);
    });
  });
  describe("prefix prop", function () {
    it("sets custom prefix", function () {
      var prefix = /*#__PURE__*/_react["default"].createElement(_reactFontawesome.FontAwesomeIcon, {
        icon: _freeSolidSvgIcons.faFlag
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        prefix: prefix,
        readOnly: true
      }));
      expect(wrapper.find(".content").children().contains(prefix)).toEqual(true);
    });
  });
  describe("suffix prop", function () {
    it("sets custom suffix", function () {
      var suffix = /*#__PURE__*/_react["default"].createElement(_reactFontawesome.FontAwesomeIcon, {
        icon: _freeSolidSvgIcons.faFlag
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        suffix: suffix,
        readOnly: true
      }));
      expect(wrapper.find(".content").children().contains(suffix)).toEqual(true);
    });
  });
  describe("size prop", function () {
    it("sets the size class", function () {
      var size = "small";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        size: size
      }));
      expect(wrapper.find("RadioButton").childAt(0).hasClass(size)).toEqual(true);
    });
  });
  describe("wrapperProps prop", function () {
    it("passes given wrapperProps attributes", function () {
      var wrapperProps = {
        id: "yo"
      };
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        wrapperProps: wrapperProps
      }));
      expect(wrapper.find("div").at(0).props().id).toEqual("yo");
    });
  });
});