"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _RadioButtonGroup = _interopRequireDefault(require("./RadioButtonGroup"));

var _RadioButton = _interopRequireDefault(require("./RadioButton"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<RadioButtonGroup>", function () {
  it("renders without errors", function () {
    var error;

    var child = /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], null);

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButtonGroup["default"], null, child));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var child = /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], null);

    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButtonGroup["default"], null, child));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("children prop", function () {
    it("renders non null children", function () {
      var child = /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        id: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButtonGroup["default"], null, null, child));
      var childrenNodes = wrapper.find(".radioButtons").children();
      expect(childrenNodes.at(0).props().id).toEqual("one");
    });
  });
  describe("error prop", function () {
    it("displays error", function () {
      var error = /*#__PURE__*/_react["default"].createElement("span", null, "an error!");

      var child = /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        id: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButtonGroup["default"], {
        error: error
      }, child));
      expect(wrapper.find("fieldset").contains(error)).toEqual(true);
    });
  });
  describe("fullWidth prop", function () {
    it("has correct classes", function () {
      var child = /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        id: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButtonGroup["default"], {
        fullWidth: true
      }, child));
      expect(wrapper.find("fieldset").childAt(0).hasClass("fullWidth")).toBeTruthy();
    });
  });
  describe("hint prop", function () {
    it("renders InputLabel when hint is provided", function () {
      var hint = "it's a hint";

      var child = /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        id: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButtonGroup["default"], {
        hint: hint
      }, child));
      expect(wrapper.find("InputLabel")).toHaveLength(1);
    });
    it("passes given hint to InputLabel", function () {
      var hint = "it's a hint";

      var child = /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        id: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButtonGroup["default"], {
        hint: hint
      }, child));
      expect(wrapper.find("InputLabel").props().hint).toEqual(hint);
    });
  });
  describe("label prop", function () {
    it("passes label to InputLabel as children", function () {
      var label = "it's a label";

      var child = /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        id: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButtonGroup["default"], {
        label: label
      }, child));
      expect(wrapper.find("InputLabel").props().children).toEqual(label);
    });
    it("does not render InputLabel when both label and hint are not provided", function () {
      var child = /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        id: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButtonGroup["default"], null, child));
      expect(wrapper.find("InputLabel")).toHaveLength(0);
    });
  });
  describe("name prop", function () {
    it("passes given name to InputLabel as htmlFor prop", function () {
      var name = "hello";
      var label = "it's a label";

      var child = /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        id: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButtonGroup["default"], {
        name: name,
        label: label
      }, child));
      expect(wrapper.find("InputLabel").props().htmlFor).toEqual(name);
    });
  });
  describe("onChange prop", function () {
    it("sets onChange prop of children nodes", function () {
      var child = /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        id: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButtonGroup["default"], null, child));
      expect(wrapper.find("RadioButton").props().onChange).toBeDefined();
    });
    it("invokes handler when child RadioButton is changed", function () {
      var child = /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        id: "one"
      });

      var onChange = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButtonGroup["default"], {
        onChange: onChange
      }, child));
      wrapper.find("RadioButton").find("input").invoke("onChange")({
        target: {
          value: "a"
        }
      });
      expect(onChange).toHaveBeenCalledWith({
        target: {
          value: "a"
        }
      }, "a");
    });
  });
  describe("required prop", function () {
    it("passes required prop to InputLabel", function () {
      var child = /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        id: "one"
      });

      var required = true;
      var label = "it's a label";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButtonGroup["default"], {
        required: required,
        label: label
      }, child));
      expect(wrapper.find("InputLabel").props().required).toEqual(required);
    });
  });
  describe("value prop", function () {
    it("sets the childs checked prop according to the value", function () {
      var child = /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        value: "one",
        id: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButtonGroup["default"], {
        value: "one"
      }, child));
      expect(wrapper.find("RadioButton").props().checked).toEqual(true);
    });
  });
  describe("variant prop", function () {
    it("sets the connected variant class when variant is connected", function () {
      var child = /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        value: "one",
        id: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButtonGroup["default"], {
        variant: "connected"
      }, child));
      expect(wrapper.find(".radioButtons.connected").length).toEqual(1);
    });
    it("sets the separate variant class when variant is separate", function () {
      var child = /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        value: "one",
        id: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButtonGroup["default"], {
        variant: "separate"
      }, child));
      expect(wrapper.find(".radioButtons.separate").length).toEqual(1);
    });
  });
  describe("warning prop", function () {
    it("displays warning", function () {
      var warning = "oh no";

      var child = /*#__PURE__*/_react["default"].createElement(_RadioButton["default"], {
        id: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioButtonGroup["default"], {
        warning: warning
      }, child));
      expect(wrapper.find("fieldset").contains(warning)).toEqual(true);
    });
  });
});