"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _RadioGroup = _interopRequireDefault(require("./RadioGroup.jsx"));

var _Radio = _interopRequireDefault(require("./Radio.jsx"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<RadioGroup>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioGroup["default"], null));
    } catch (theError) {
      error = theError;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioGroup["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("children prop", function () {
    it("renders given non null children", function () {
      var child = /*#__PURE__*/_react["default"].createElement(_Radio["default"], {
        label: "one",
        readOnly: true
      });

      var child2 = /*#__PURE__*/_react["default"].createElement(_Radio["default"], {
        label: "two",
        readOnly: true
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioGroup["default"], null, child, null, child2));
      var childrenNodes = wrapper.find("fieldset").find("Radio");
      expect(childrenNodes.at(0).props().label).toEqual("one");
      expect(childrenNodes.at(1).props().label).toEqual("two");
    });
  });
  describe("error prop", function () {
    it("displays error", function () {
      var error = /*#__PURE__*/_react["default"].createElement("span", null, "an error!");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioGroup["default"], {
        error: error
      }));
      expect(wrapper.find("fieldset").contains(error)).toEqual(true);
    });
  });
  describe("hint prop", function () {
    it("renders InputLabel when hint is provided", function () {
      var hint = "it's a hint";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioGroup["default"], {
        hint: hint
      }));
      expect(wrapper.find("InputLabel")).toHaveLength(1);
    });
    it("passes given hint to InputLabel", function () {
      var hint = "it's a hint";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioGroup["default"], {
        hint: hint
      }));
      expect(wrapper.find("InputLabel").props().hint).toEqual(hint);
    });
  });
  describe("label prop", function () {
    it("renders Inputlabel and passes label to InputLabel as children", function () {
      var label = "it's a label";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioGroup["default"], {
        label: label
      }));
      expect(wrapper.find("InputLabel").props().children).toEqual(label);
      expect(wrapper.find("InputLabel")).toHaveLength(1);
    });
    it("does not render InputLabel when both label and hint are not provided", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioGroup["default"], null));
      expect(wrapper.find("InputLabel")).toHaveLength(0);
    });
  });
  describe("name prop", function () {
    it("passes given name to InputLabel as htmlFor prop", function () {
      var name = "hello";
      var label = "it's a label";

      var child = /*#__PURE__*/_react["default"].createElement(_Radio["default"], {
        id: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioGroup["default"], {
        name: name,
        label: label
      }, child));
      expect(wrapper.find("InputLabel").props().htmlFor).toEqual(name);
    });
  });
  describe("onChange prop", function () {
    it("sets onChange prop of children nodes", function () {
      var child = /*#__PURE__*/_react["default"].createElement(_Radio["default"], {
        label: "one",
        readOnly: true
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioGroup["default"], null, child));
      expect(wrapper.find("Radio").props().onChange).toBeDefined();
    });
    it("invokes handler when child Radio is changed", function () {
      var child = /*#__PURE__*/_react["default"].createElement(_Radio["default"], {
        label: "one",
        readOnly: true
      });

      var onChange = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioGroup["default"], {
        onChange: onChange
      }, child));
      wrapper.find("Radio").find("input").invoke("onChange")({
        target: {
          value: "a"
        }
      });
      expect(onChange).toHaveBeenCalledWith({
        target: {
          value: "a"
        }
      }, "a");
    });
  });
  describe("required prop", function () {
    it("passes required prop to InputLabel", function () {
      var label = "it's a label";
      var required = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioGroup["default"], {
        label: label,
        required: required
      }));
      expect(wrapper.find("InputLabel").props().required).toEqual(required);
    });
  });
  describe("suffix prop", function () {
    it("passes suffix prop to InputLabel", function () {
      var suffix = /*#__PURE__*/_react["default"].createElement("span", null, "\"Test\"");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioGroup["default"], {
        suffix: suffix
      }));
      expect(wrapper.find("InputLabel").props().suffix).toEqual(suffix);
    });
  });
  describe("value prop", function () {
    it("sets the childs checked prop according to the value", function () {
      var child = /*#__PURE__*/_react["default"].createElement(_Radio["default"], {
        value: "one",
        id: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioGroup["default"], {
        value: "one"
      }, child));
      expect(wrapper.find("Radio").props().checked).toEqual(true);
    });
  });
  describe("warning prop", function () {
    it("displays warning", function () {
      var warning = "oh no";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_RadioGroup["default"], {
        warning: warning
      }));
      expect(wrapper.find("fieldset").contains(warning)).toEqual(true);
    });
  });
});