"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _Switch = _interopRequireDefault(require("./Switch"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Switch>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Switch["default"], {
        readOnly: true
      }));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Switch["default"], {
      readOnly: true
    }));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Switch["default"], {
        readOnly: true
      }));
      var component = wrapper.find("Switch");
      expect(component.props().checked).toEqual(false);
      expect(component.props().classes).toEqual([]);
      expect(component.props().color).toEqual("secondary");
      expect(component.props().size).toEqual("medium");
    });
  });
  describe("checked prop", function () {
    it("passes given checked value to input element", function () {
      var checked = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Switch["default"], {
        checked: checked,
        readOnly: true
      }));
      expect(wrapper.find("input").props().checked).toEqual(checked);
    });
  });
  describe("classes prop", function () {
    it("applies given classes to the root node", function () {
      var classes = ["classOne"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Switch["default"], {
        classes: classes,
        readOnly: true
      }));
      expect(wrapper.find("Switch").childAt(0).hasClass(classes[0])).toEqual(true);
    });
  });
  describe("color prop", function () {
    it("applies valid custom color class name", function () {
      var color = "positive";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Switch["default"], {
        color: color,
        readOnly: true
      }));
      expect(wrapper.find("input").hasClass(color)).toEqual(true);
    });
    it("gives an error given an invalid color", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var color = "default";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Switch["default"], {
        color: color,
        readOnly: true
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("disabled prop", function () {
    it("passes given disabled value to input element", function () {
      var disabled = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Switch["default"], {
        disabled: disabled
      }));
      expect(wrapper.find("input").props().disabled).toEqual(true);
    });
  });
  describe("id", function () {
    it("passes given id value to input element", function () {
      var id = "ID";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Switch["default"], {
        id: id,
        readOnly: true
      }));
      expect(wrapper.find("input").props().id).toEqual(id);
    });
  });
  describe("onChange prop", function () {
    it("invokes onChange handler on change event", function () {
      var onChange = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Switch["default"], {
        onChange: onChange,
        checked: true
      }));
      wrapper.find("input").invoke("onChange")();
      expect(onChange).toHaveBeenCalledTimes(1);
    });
  });
  describe("required prop", function () {
    it("passes given required value to input element", function () {
      var required = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Switch["default"], {
        required: required,
        readOnly: true
      }));
      expect(wrapper.find("input").props().required).toEqual(required);
    });
  });
  describe("size prop", function () {
    it("applies valid custom size class name to input element", function () {
      var size = "small";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Switch["default"], {
        size: size,
        readOnly: true
      }));
      expect(wrapper.find("input").hasClass(size)).toEqual(true);
    });
    it("gives an error given an invalid color", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var size = "large";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Switch["default"], {
        size: size,
        readOnly: true
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("value prop", function () {
    it("passes given value to input element", function () {
      var value = "pizza";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Switch["default"], {
        value: value,
        readOnly: true
      }));
      expect(wrapper.find("input").props().value).toEqual(value);
    });
  });
});