"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _reactFontawesome = require("@fortawesome/react-fontawesome");

var _freeSolidSvgIcons = require("@fortawesome/free-solid-svg-icons");

var _Tab = _interopRequireDefault(require("./Tab"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var icon = function icon(i) {
  return function (props) {
    return /*#__PURE__*/_react["default"].createElement(_reactFontawesome.FontAwesomeIcon, _extends({
      icon: i
    }, props));
  };
};

describe("<Tab>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        value: true
      }));
    } catch (theError) {
      error = theError;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
      value: true
    }));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        value: true
      }));
      expect(wrapper.find("Tab").props().active).toEqual(false);
      expect(wrapper.find("Tab").props().breakpoint).toEqual("sm");
      expect(wrapper.find("Tab").props().color).toEqual("secondary");
      expect(wrapper.find("Tab").props().disabled).toEqual(false);
      expect(wrapper.find("Tab").props().fullWidth).toEqual(false);
      expect(wrapper.find("Tab").props().letterSpacing).toEqual(1);
      expect(wrapper.find("Tab").props().orientation).toEqual("horizontal");
      expect(wrapper.find("Tab").props().textTransform).toEqual("uppercase");
    });
  });
  describe("active props", function () {
    it("sets correct class name based on color when active is true", function () {
      var active = true;
      var color = "primary";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        active: active,
        color: color,
        value: true
      }));
      expect(wrapper.find("Tab").childAt(0).hasClass("".concat(color, "-active"))).toEqual(true);
    });
    it("sets correct class name based on orientation when active is true", function () {
      var active = true;
      var orientation = "horizontal";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        active: active,
        orientation: orientation,
        value: true
      }));
      expect(wrapper.find("Tab").childAt(0).hasClass("".concat(orientation, "-active"))).toEqual(true);
    });
  });
  describe("breakpoint prop", function () {
    describe("custom breakpoint and orientation props", function () {
      var tests = [{
        props: {
          breakpoint: "md",
          orientation: "horizontal"
        },
        expected: true
      }, {
        props: {
          breakpoint: "md",
          orientation: "vertical"
        },
        expected: false
      }, {
        props: {
          breakpoint: "none",
          orientation: "horizontal"
        },
        expected: false
      }];
      tests.forEach(function (test) {
        it("".concat(test.expected ? "does" : "does not", " set breakpoint class name with breakpoint of ").concat(test.props.breakpoint, " and orientation of ").concat(test.props.orientation), function () {
          var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], _extends({}, test.props, {
            value: true
          })));
          expect(wrapper.find("Tab").childAt(0).hasClass("breakpoint")).toEqual(test.expected);
        });
      });
    });
    it("gives an error when given an invalid breakpoint", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var breakpoint = "xs";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        breakpoint: breakpoint,
        value: true
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("classes prop", function () {
    it("sets custom class", function () {
      var classes = ["newClass"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        classes: classes,
        value: true
      }));
      expect(wrapper.find("Tab").childAt(0).hasClass(classes[0])).toEqual(true);
    });
  });
  describe("color prop", function () {
    it("sets custom valid color", function () {
      var color = "secondary";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        color: color,
        value: true
      }));
      expect(wrapper.find("Tab").childAt(0).hasClass(color)).toEqual(true);
    });
    it("gives an error when given an invalid color", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var color = "tertiary";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        color: color,
        value: true
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("disabled prop", function () {
    it("sets disabled class name with valid custom disabled", function () {
      var disabled = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        disabled: disabled,
        value: true
      }));
      expect(wrapper.find("Tab").childAt(0).hasClass("disabled")).toEqual(true);
    });
  });
  describe("displayActive props", function () {
    it("sets correct class name based on color when displayActive is true", function () {
      var displayActive = true;
      var color = "primary";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        displayActive: displayActive,
        color: color,
        value: true
      }));
      expect(wrapper.find("Tab").childAt(0).hasClass("".concat(color, "-active"))).toEqual(true);
    });
    it("sets correct class name based on orientation when displayActive is true", function () {
      var displayActive = true;
      var orientation = "horizontal";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        displayActive: displayActive,
        orientation: orientation,
        value: true
      }));
      expect(wrapper.find("Tab").childAt(0).hasClass("".concat(orientation, "-active"))).toEqual(true);
    });
  });
  describe("fullWidth prop", function () {
    it("sets fullWidth class name with valid custom fullWidth", function () {
      var fullWidth = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        fullWidth: fullWidth,
        value: true
      }));
      expect(wrapper.find("Tab").childAt(0).hasClass("full-width")).toEqual(true);
    });
  });
  describe("icon prop", function () {
    it("sets icon class name with valid custom icon", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        icon: icon(_freeSolidSvgIcons.faPhone),
        value: true
      }));
      expect(wrapper.find("Tab").childAt(0).childAt(0).hasClass("icon")).toEqual(true);
    });
    it("renders icon when icon is node", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        icon: "bob",
        value: true
      }));
      expect(wrapper.text()).toEqual("bob");
    });
  });
  describe("label prop", function () {
    it("sets label class name with valid custom label", function () {
      var label = "Test";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        label: label,
        value: true
      }));
      expect(wrapper.find("Tab").childAt(0).childAt(0).hasClass("label")).toEqual(true);
      expect(wrapper.text()).toEqual(label);
    });
  });
  describe("onClick prop", function () {
    it("invokes onClick prop on click", function () {
      var handler = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        onClick: handler,
        value: true
      }));
      wrapper.find("Tab").childAt(0).invoke("onClick")({
        type: "click"
      });
      expect(handler).toHaveBeenCalledTimes(1);
    });
    it("does not invoke onClick prop on click when disabled", function () {
      var handler = jest.fn();
      var disabled = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        onClick: handler,
        disabled: disabled,
        value: true
      }));
      wrapper.find("Tab").childAt(0).invoke("onClick")({
        type: "click"
      });
      expect(handler).toHaveBeenCalledTimes(0);
    });
    it("invokes onClick prop on valid keydown event", function () {
      var handler = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        onClick: handler,
        value: true
      }));
      wrapper.find("Tab").childAt(0).invoke("onClick")({
        key: "Enter",
        type: "keydown"
      });
      expect(handler).toHaveBeenCalledTimes(1);
    });
    it("does not invoke onClick prop on invalid keydown event", function () {
      var handler = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        onClick: handler,
        value: true
      }));
      wrapper.find("Tab").childAt(0).invoke("onClick")({
        key: "3",
        type: "keydown"
      });
      expect(handler).toHaveBeenCalledTimes(0);
    });
  });
  describe("orientation prop", function () {
    it("sets orientation class name with valid custom orientation", function () {
      var orientation = "vertical";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        orientation: orientation,
        value: true
      }));
      expect(wrapper.find("Tab").childAt(0).hasClass(orientation)).toEqual(true);
    });
    it("gives an error when given an invalid orientation", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var orientation = "upright";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        orientation: orientation,
        value: true
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("focusVisible state", function () {
    it("sets correct class name when focus event occurs", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        value: true
      }));
      wrapper.find("Tab").childAt(0).invoke("onFocus")({});
      expect(wrapper.find("Tab").childAt(0).hasClass("focusVisible")).toBeTruthy();
    });
    it("sets correct class name when blur event occurs", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        value: true
      }));
      wrapper.find("Tab").childAt(0).invoke("onFocus")({});
      wrapper.find("Tab").childAt(0).invoke("onBlur")();
      expect(wrapper.find("Tab").childAt(0).hasClass("focusVisible")).toBeFalsy();
    });
  });
  describe("letterSpacing prop", function () {
    it("gives an error when given an invalid letterSpacing", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var letterSpacing = "invalid";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        letterSpacing: letterSpacing,
        value: true
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("textTransform prop", function () {
    it("gives an error when given an invalid textTransform", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var textTransform = "upright";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        textTransform: textTransform,
        value: true
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
});