"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _default = _interopRequireDefault(require("../themes/default"));

var _Table = _interopRequireDefault(require("./Table"));

var _TableHeader = _interopRequireDefault(require("./TableHeader"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Table>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], null));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], null));
      var component = wrapper.find("Table");
      expect(component.props().backgroundColor).toEqual("grey50");
      expect(component.props().layout).toEqual("auto");
    });
  });
  describe("backgroundColor prop", function () {
    it("sets custom valid backgroundColor with mapped hex color", function () {
      var color = "grey400";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], {
        backgroundColor: color
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain("".concat(_default["default"].palette.grey[400]));
    });
    it("gives an error given an invalid backgroundColor", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var color = "white";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], {
        backgroundColor: color
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("children prop", function () {
    it("renders all non null children", function () {
      var child = /*#__PURE__*/_react["default"].createElement(_TableHeader["default"], null);

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], null, null, child));
      expect(wrapper.find("Table").contains(child)).toEqual(true);
    });
  });
  describe("classes prop", function () {
    it("applies all classes to the root node", function () {
      var classes = ["classOne"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], {
        classes: classes
      }));
      expect(wrapper.find("Table").childAt(0).hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClass decorator", function () {
      var classes = ["riipen", "riipen-table"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], null));
      expect(wrapper.find("Table").props().classes.sort()).toEqual(classes.sort());
    });
  });
  describe("layout prop", function () {
    it("applies valid custom layout", function () {
      var layout = "fixed";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], {
        layout: layout
      }));
      expect(wrapper.find("JSXStyle").props().dynamic).toContain(layout);
    });
    it("gives an error given an invalid layout", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var layout = "left";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], {
        layout: layout
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
});