"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _default = _interopRequireDefault(require("../themes/default"));

var _TableRow = _interopRequireDefault(require("./TableRow"));

var _Table = _interopRequireDefault(require("./Table"));

var _TableHeader = _interopRequireDefault(require("./TableHeader"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<TableRow>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], null, /*#__PURE__*/_react["default"].createElement(_TableHeader["default"], null, /*#__PURE__*/_react["default"].createElement(_TableRow["default"], null))));
    } catch (theError) {
      error = theError;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], null, /*#__PURE__*/_react["default"].createElement(_TableHeader["default"], null, /*#__PURE__*/_react["default"].createElement(_TableRow["default"], null))));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var defaultProps = new _TableRow["default"]().type.defaultProps;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], null, /*#__PURE__*/_react["default"].createElement(_TableHeader["default"], null, /*#__PURE__*/_react["default"].createElement(_TableRow["default"], null))));
      expect(wrapper.find("TableRow").props().border).toEqual(defaultProps.border);
      expect(wrapper.find("TableRow").props().forceHover).toEqual(defaultProps.forceHover);
    });
  });
  describe("border prop", function () {
    it("sets border with custom color when border is true", function () {
      var border = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], null, /*#__PURE__*/_react["default"].createElement(_TableHeader["default"], null, /*#__PURE__*/_react["default"].createElement(_TableRow["default"], {
        border: border
      }))));
      expect(wrapper.find("TableRow").find("JSXStyle").props().dynamic).toContain(_default["default"].palette.divider);
    });
    it("does not set border when border is false", function () {
      var border = false;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], null, /*#__PURE__*/_react["default"].createElement(_TableHeader["default"], null, /*#__PURE__*/_react["default"].createElement(_TableRow["default"], {
        border: border
      }))));
      expect(wrapper.find("TableRow").find("JSXStyle").props().dynamic).not.toContain(_default["default"].palette.divider);
    });
  });
  describe("children prop", function () {
    it("displays given children", function () {
      var child = /*#__PURE__*/_react["default"].createElement("td", null, "Test");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], null, /*#__PURE__*/_react["default"].createElement(_TableHeader["default"], null, /*#__PURE__*/_react["default"].createElement(_TableRow["default"], null, child))));
      expect(wrapper.containsMatchingElement(child)).toBeTruthy();
    });
  });
  describe("classes prop", function () {
    it("applies all classes to the tbody node", function () {
      var classes = ["classOne"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], null, /*#__PURE__*/_react["default"].createElement(_TableHeader["default"], null, /*#__PURE__*/_react["default"].createElement(_TableRow["default"], {
        classes: classes
      }))));
      expect(wrapper.find("tr").hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClass decorator", function () {
      var classes = ["riipen", "riipen-tablerow"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], null, /*#__PURE__*/_react["default"].createElement(_TableHeader["default"], null, /*#__PURE__*/_react["default"].createElement(_TableRow["default"], null))));
      expect(wrapper.find("TableRow").props().classes.sort()).toEqual(classes.sort());
    });
  });
  describe("forceHover prop", function () {
    it("sets correct class name when forceHover is true", function () {
      var forceHover = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], null, /*#__PURE__*/_react["default"].createElement(_TableHeader["default"], null, /*#__PURE__*/_react["default"].createElement(_TableRow["default"], {
        forceHover: forceHover
      }))));
      expect(wrapper.find("tr").hasClass("forceHover")).toEqual(true);
    });
  });
  describe("hover prop", function () {
    it("sets background color when hover is true", function () {
      var hover = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], null, /*#__PURE__*/_react["default"].createElement(_TableHeader["default"], null, /*#__PURE__*/_react["default"].createElement(_TableRow["default"], {
        hover: hover
      }))));
      expect(wrapper.find("TableRow").find("JSXStyle").props().dynamic).toContain("background-color: ".concat(_default["default"].palette.common.white, ";"));
    });
    it("does not set background color when hover is false", function () {
      var hover = false;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], null, /*#__PURE__*/_react["default"].createElement(_TableHeader["default"], null, /*#__PURE__*/_react["default"].createElement(_TableRow["default"], {
        hover: hover
      }))));
      expect(wrapper.find("TableRow").find("JSXStyle").props().dynamic).not.toContain("background-color: ".concat(_default["default"].palette.common.white, ";"));
    });
    it("sets border-left as solid when hover is true", function () {
      var hover = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], null, /*#__PURE__*/_react["default"].createElement(_TableHeader["default"], null, /*#__PURE__*/_react["default"].createElement(_TableRow["default"], {
        hover: hover
      }))));
      expect(wrapper.find("TableRow").find("JSXStyle").props().dynamic).toContain("border-left: 3px solid ".concat(_default["default"].palette.secondary.main, ";"));
    });
    it("does not set border-left as solid when hover is false", function () {
      var hover = false;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Table["default"], null, /*#__PURE__*/_react["default"].createElement(_TableHeader["default"], null, /*#__PURE__*/_react["default"].createElement(_TableRow["default"], {
        hover: hover
      }))));
      expect(wrapper.find("TableRow").find("JSXStyle").props().dynamic).not.toContain("border-left: 3px solid ".concat(_default["default"].palette.secondary.main, ";"));
    });
  });
});