"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _Tab = _interopRequireDefault(require("./Tab"));

var _Tabs = _interopRequireDefault(require("./Tabs"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Tabs>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], null));
    } catch (theError) {
      error = theError;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var defaultProps = new _Tabs["default"]().type.defaultProps;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], null));
      var component = wrapper.find("Tabs");
      expect(component.props().breakpoint).toEqual(defaultProps.breakpoint);
      expect(component.props().color).toEqual(defaultProps.color);
      expect(component.props().component).toEqual(defaultProps.component);
      expect(component.props().orientation).toEqual(defaultProps.orientation);
      expect(component.props().variant).toEqual(defaultProps.variant);
    });
  });
  describe("breakpoint prop", function () {
    it("passes valid given breakpoint to children nodes", function () {
      var breakpoint = "xl";

      var child = /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        label: "Item one",
        value: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], {
        breakpoint: breakpoint
      }, child));
      var childrenNode = wrapper.find("Tab");
      expect(childrenNode.props().breakpoint).toEqual(breakpoint);
    });
    it("gives an error with invalid breakpoint", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], {
        breakpoint: "xs"
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("children prop", function () {
    it("renders all non null children", function () {
      var child1 = /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        value: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], null, null, child1));
      var childrenNodes = wrapper.find("Tab");
      expect(childrenNodes.at(0).props().value).toEqual("one");
    });
  });
  describe("classes prop", function () {
    it("applies all classes to the root node", function () {
      var classes = ["classOne"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], {
        classes: classes
      }));
      expect(wrapper.find("Tabs").childAt(0).hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClass decorator", function () {
      var classes = ["riipen", "riipen-tabs"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], null));
      expect(wrapper.find("Tabs").props().classes.sort()).toEqual(classes.sort());
    });
  });
  describe("color prop", function () {
    it("passes valid given color to children", function () {
      var color = "primary";

      var child = /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        label: "Item one",
        value: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], {
        color: color
      }, child));
      expect(wrapper.find("Tab").props().color).toEqual(color);
    });
    it("gives an error with invalid color", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], {
        color: "yellow"
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("component prop", function () {
    it("applies given component to the root node", function () {
      var component = "h3";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], {
        component: component
      }));
      expect(wrapper.find("Tabs").childAt(0).name()).toEqual(component);
    });
    it("gives an error when given an invalid component", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var component = "abcd";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], {
        component: component
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("letterSpacing prop", function () {
    it("sets letterSpacing in children nodes", function () {
      var letterSpacing = 5;

      var child = /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        label: "Item one",
        value: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], {
        letterSpacing: letterSpacing
      }, child));
      expect(wrapper.find("Tab").props().letterSpacing).toEqual(5);
    });
    it("gives an error with invalid letterSpacing", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], {
        letterSpacing: "invalid"
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("onChange prop", function () {
    it("sets onClick prop of children nodes", function () {
      var child = /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        label: "Item one",
        value: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], null, child));
      expect(wrapper.find("Tab").props().onClick).not.toBeNull();
    });
    it("invokes handler when child Tab is clicked", function () {
      var onChange = jest.fn();

      var child = /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        label: "Item one",
        value: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], {
        onChange: onChange
      }, child));
      wrapper.find("Tab").childAt(0).invoke("onClick")({
        type: "click"
      });
      expect(onChange).toHaveBeenCalledWith(expect.any(Object), "one");
    });
  });
  describe("orientation prop", function () {
    it("passes given valid orientation to children", function () {
      var orientation = "vertical";

      var child = /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        label: "Item one",
        value: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], {
        orientation: orientation
      }, child));
      expect(wrapper.find("Tab").props().orientation).toEqual(orientation);
    });
    it("sets valid custom orientation", function () {
      var orientation = "vertical";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], {
        orientation: orientation
      }));
      expect(wrapper.find("Tabs").childAt(0).childAt(0).childAt(0).hasClass(orientation)).toEqual(true);
    });
    it("gives an error with invalid orientation", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], {
        orientation: "forward"
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("value prop", function () {
    it("sets the Tab with the corresponding value prop as active", function () {
      var child1 = /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        label: "Item one",
        value: "one"
      });

      var child2 = /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        label: "Item two",
        value: "two"
      });

      var value = "two";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], {
        value: value
      }, child1, child2));
      var childrenNodes = wrapper.find("Tab");
      expect(childrenNodes.at(0).props().active).toEqual(false);
      expect(childrenNodes.at(1).props().active).toEqual(true);
    });
  });
  describe("textTransform prop", function () {
    it("sets textTransform in children nodes", function () {
      var textTransform = "lowercase";

      var child = /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        label: "Item one",
        value: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], {
        textTransform: textTransform
      }, child));
      expect(wrapper.find("Tab").props().textTransform).toEqual("lowercase");
    });
    it("gives an error with invalid textTransform", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], {
        textTransform: "invalid"
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("variant prop", function () {
    it("sets fullWidth to be true in children nodes when variant is fullWidth", function () {
      var variant = "fullWidth";

      var child = /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        label: "Item one",
        value: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], {
        variant: variant
      }, child));
      expect(wrapper.find("Tab").props().fullWidth).toEqual(true);
    });
    it("sets fullWidth to be false in children nodes when variant is standard", function () {
      var variant = "standard";

      var child = /*#__PURE__*/_react["default"].createElement(_Tab["default"], {
        label: "Item one",
        value: "one"
      });

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], {
        variant: variant
      }, child));
      expect(wrapper.find("Tab").props().fullWidth).toEqual(false);
    });
    it("gives an error with invalid variant", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tabs["default"], {
        variant: "invalid"
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
});