"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _Tooltip = _interopRequireDefault(require("./Tooltip.jsx"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Tooltip>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], null));
    } catch (e) {
      error = e;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("children prop", function () {
    it("renders the children", function () {
      var children = "test";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], null, children));
      expect(wrapper.text()).toEqual(children);
    });
  });
  describe("classes prop", function () {
    it("applies all classes to the popover node", function () {
      var classes = ["classOne"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        classes: classes
      }));
      expect(wrapper.find("Tooltip").find("Popover").props().classes).toContain(classes[0]);
    });
    it("appends higher order values to classes prop with withClass decorator", function () {
      var classes = ["riipen", "riipen-tooltip"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], null));
      expect(wrapper.find("Tooltip").props().classes.sort()).toEqual(classes.sort());
    });
  });
  describe("click prop", function () {
    it("invokes click when click is true", function () {
      var click = true;
      var onOpen = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        click: click,
        onOpen: onOpen
      }));
      wrapper.find("div").at(0).invoke("onClick")();
      expect(onOpen).toHaveBeenCalledTimes(1);
    });
  });
  describe("color prop", function () {
    it("sets tooltip color with given valid custom color prop", function () {
      var color = "positive";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        color: color
      }));
      expect(wrapper.find("Tooltip").find("Popover").props().classes).toContain(color);
    });
    it("gives an error given invalid color", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var color = "bad";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        color: color
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("component prop", function () {
    it("sets custom component", function () {
      var component = "span";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        component: component
      }));
      expect(wrapper.find("Tooltip").childAt(0).name()).toEqual(component);
    });
    it("sets component type to div when component prop is not provided", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], null));
      expect(wrapper.find("Tooltip").childAt(0).name()).toEqual("div");
    });
  });
  describe("hover prop", function () {
    it("opens tooltip on mouse enter when hover is true", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], null));
      wrapper.find("div").at(0).invoke("onMouseEnter")();
      expect(wrapper.find("Popover").props().isOpen).toBe(true);
    });
    it("closes tooltip on mouse leave when hover is true", function () {
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], null));
      wrapper.find("div").at(0).invoke("onMouseEnter")();
      wrapper.find("div").at(0).invoke("onMouseLeave")();
      expect(wrapper.find("Popover").props().isOpen).toBe(false);
    });
    it("does not open tooltip on mouse enter when hover is false", function () {
      var hover = false;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        hover: hover
      }));
      expect(wrapper.find("div").at(0).props().onMouseEnter).toBeNull();
      expect(wrapper.find("Popover").props().isOpen).toBe(false);
    });
    it("does not close tooltip on mouse leave when hover is false", function () {
      var hover = false;
      var click = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        click: click,
        hover: hover
      }));
      wrapper.find("div").at(0).invoke("onClick")();
      expect(wrapper.find("div").at(0).props().onMouseLeave).toBeNull();
      expect(wrapper.find("Popover").props().isOpen).toBe(true);
    });
  });
  describe("isControlledByProps prop", function () {
    it("does not open tooltip on mouse enter when onOpen not provided", function () {
      var isControlledByProps = true;
      var open = false;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        isControlledByProps: isControlledByProps,
        open: open
      }));
      wrapper.find("div").at(0).invoke("onMouseEnter")();
      expect(wrapper.find("Popover").props().isOpen).toBe(false);
    });
    it("does not close tooltip on mouse leave when onOpen not provided", function () {
      var isControlledByProps = true;
      var open = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        isControlledByProps: isControlledByProps,
        open: open
      }));
      wrapper.find("div").at(0).invoke("onMouseLeave")();
      expect(wrapper.find("Popover").props().isOpen).toBe(true);
    });
  });
  describe("keepOpenOnMouseLeave prop", function () {
    it("does not close tooltip on mouse leave", function () {
      var keepOpenOnMouseLeave = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        keepOpenOnMouseLeave: keepOpenOnMouseLeave
      }));
      wrapper.find("div").at(0).invoke("onMouseEnter")();
      expect(wrapper.find("div").at(0).props().onMouseLeave).toBeNull();
      expect(wrapper.find("Popover").props().isOpen).toBe(true);
    });
  });
  describe("onClose prop", function () {
    it("invokes onOpen prop on mouse leave", function () {
      var onClose = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        onClose: onClose
      }));
      wrapper.find("div").at(0).invoke("onMouseLeave")();
      expect(onClose).toHaveBeenCalledTimes(1);
    });
    it("invokes onClose prop on click when click is true", function () {
      var click = true;
      var onClose = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        click: click,
        onClose: onClose
      })); // open and close tooltip

      wrapper.find("div").at(0).invoke("onClick")();
      wrapper.find("div").at(0).invoke("onClick")();
      expect(onClose).toHaveBeenCalledTimes(1);
    });
  });
  describe("onKeyDown prop", function () {
    it("passes onKeyDown to Popover", function () {
      var onKeyDown = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        onKeyDown: onKeyDown
      }));
      expect(wrapper.find("Popover").props().onKeyDown).toEqual(onKeyDown);
    });
  });
  describe("onOpen prop", function () {
    it("invokes onOpen prop on mouse enter", function () {
      var onOpen = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        onOpen: onOpen
      }));
      wrapper.find("div").at(0).invoke("onMouseEnter")();
      expect(onOpen).toHaveBeenCalledTimes(1);
    });
    it("invokes onOpen prop on click when click is true", function () {
      var click = true;
      var onOpen = jest.fn();
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        click: click,
        onOpen: onOpen
      }));
      wrapper.find("div").at(0).invoke("onClick")();
      expect(onOpen).toHaveBeenCalledTimes(1);
    });
  });
  describe("open prop", function () {
    it("passes open to Popover as true when provided", function () {
      var isControlledByProps = true;
      var open = true;
      var tooltip = "test";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        isControlledByProps: isControlledByProps,
        open: open,
        tooltip: tooltip
      }));
      expect(wrapper.find("Popover").props().isOpen).toBe(true);
    });
  });
  describe("position prop", function () {
    it("passes correct position class to Popover", function () {
      var position = "top-left";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        position: position
      }));
      expect(wrapper.find("Tooltip").find("Popover").props().classes).toContain(position);
    });
    it("passes correct contentPosition prop to Popover", function () {
      var position = "top-left";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        position: position
      }));
      expect(wrapper.find("Tooltip").find("Popover").props().contentPosition).toStrictEqual({
        horizontal: "right",
        vertical: "bottom"
      });
    });
  });
  describe("size prop", function () {
    it("sets tooltip size with given valid custom size prop", function () {
      var size = "small";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        size: size
      }));
      expect(wrapper.find("Tooltip").find("Popover").props().classes).toContain(size);
    });
    it("gives an error given invalid size", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      var size = "sm";
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        size: size
      }));
      expect(errors).toHaveBeenCalledTimes(1);
    });
  });
  describe("tooltip prop", function () {
    it("renders tooltip inside Popover", function () {
      var tooltip = "test";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Tooltip["default"], {
        tooltip: tooltip
      }));
      expect(wrapper.find("Tooltip").find("Popover").props().children).toBe(tooltip);
    });
  });
});