"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _Typography = _interopRequireDefault(require("./Typography"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<Typography>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], null));
    } catch (theError) {
      error = theError;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("default props", function () {
    it("sets correct default props", function () {
      var defaultProps = new _Typography["default"]().type.defaultProps;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], null));
      var component = wrapper.find("Typography");
      expect(component.props().color).toEqual(defaultProps.color);
      expect(component.props().display).toEqual(defaultProps.display);
      expect(component.props().gutter).toEqual(defaultProps.gutter);
      expect(component.props().textAlign).toEqual(defaultProps.textAlign);
      expect(component.props().variant).toEqual(defaultProps.variant);
    });
  });
  describe("children prop", function () {
    it("renders given children", function () {
      var child = /*#__PURE__*/_react["default"].createElement("span", null, "this is a child");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], null, child));
      expect(wrapper.find("Typography").contains(child)).toEqual(true);
    });
  });
  describe("classes prop", function () {
    it("applies classes to the root node of Typography", function () {
      var classes = ["classOne"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        classes: classes
      }));
      expect(wrapper.find("Typography").childAt(0).hasClass(classes[0])).toEqual(true);
    });
    it("appends higher order values to classes prop with withClasses decorator", function () {
      var classes = ["riipen", "riipen-typography"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], null));
      expect(wrapper.find("Typography").props().classes.sort()).toEqual(classes.sort());
    });
    it("gives an error when classes are provided as one string", function () {
      var classes = "classOne classTwo";
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        classes: classes
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("color prop", function () {
    it("applies color class given a valid color", function () {
      var color = "white";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        color: color
      }));
      expect(wrapper.find("Typography").childAt(0).hasClass("color-".concat(color))).toEqual(true);
    });
    it("gives an error when given an invalid color", function () {
      var color = "red";
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        color: color
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("component prop", function () {
    it("sets component with valid custom component", function () {
      var component = "a";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        component: component
      }));
      expect(wrapper.find("Typography").childAt(0).name()).toEqual(component);
    });
    it("gives an error when given an invalid component", function () {
      var component = "invalidcomponent";
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        component: component
      }));
      expect(errors).toHaveBeenCalled();
    });
    it("applies the component prop over the variant prop when both are provided", function () {
      var component = "a";
      var variant = "h1";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        component: component,
        variant: variant
      }));
      expect(wrapper.find("Typography").childAt(0).name()).toEqual(component);
    });
  });
  describe("display prop", function () {
    it("sets display class with valid display", function () {
      var display = "inline";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        display: display
      }));
      expect(wrapper.find("Typography").childAt(0).hasClass(display)).toEqual(true);
    });
    it("gives an error when given an invalid display", function () {
      var display = "invalid";
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        display: display
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("fontWeight prop", function () {
    it("sets fontWeight class with valid fontWeight", function () {
      var fontWeight = "medium";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        fontWeight: fontWeight
      }));
      expect(wrapper.find("Typography").childAt(0).hasClass(fontWeight)).toEqual(true);
    });
    it("gives an error when given an invalid fontWeight", function () {
      var fontWeight = "invalid";
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        fontWeight: fontWeight
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("gutter prop", function () {
    it("applies gutter class when gutter prop is true", function () {
      var gutter = true;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        gutter: gutter
      }));
      expect(wrapper.find("Typography").childAt(0).hasClass("gutter")).toEqual(true);
    });
    it("does not apply gutter class when gutter prop is false", function () {
      var gutter = false;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        gutter: gutter
      }));
      expect(wrapper.find("Typography").childAt(0).hasClass("gutter")).toEqual(false);
    });
  });
  describe("letterSpacing prop", function () {
    it("sets custom letterSpacing when provided", function () {
      var letterSpacing = 1;
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        letterSpacing: letterSpacing
      }));
      expect(wrapper.find("Typography").props().letterSpacing).toEqual(1);
    });
    it("gives an error with invalid letterSpacing", function () {
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        letterSpacing: "invalid"
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("textAlign prop", function () {
    it("sets textAlign class given a valid textAlign prop", function () {
      var textAlign = "justify";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        textAlign: textAlign
      }));
      expect(wrapper.find("Typography").childAt(0).hasClass("align-".concat(textAlign))).toEqual(true);
    });
    it("gives an error given an invalid textAlign prop", function () {
      var textAlign = "invalid";
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        textAlign: textAlign
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("textTransform prop", function () {
    it("sets textTransform class given a valid textTransform prop", function () {
      var textTransform = "capitalize";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        textTransform: textTransform
      }));
      expect(wrapper.find("Typography").childAt(0).hasClass("transform-".concat(textTransform))).toEqual(true);
    });
    it("gives an error given an invalid textTransform prop", function () {
      var textTransform = "invalid";
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        textTransform: textTransform
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("variant prop", function () {
    it("sets valid, mapped variant to component", function () {
      var variant = "h5";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        variant: variant
      }));
      expect(wrapper.find("Typography").childAt(0).name()).toEqual(variant);
    });
    it("sets component to span when given an unmapped variant", function () {
      var variant = "inherit";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        variant: variant
      }));
      expect(wrapper.find("Typography").childAt(0).name()).toEqual("span");
    });
    it("gives an error given an invalid variant", function () {
      var variant = "invalid";
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        variant: variant
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
  describe("wordBreak prop", function () {
    it("sets wordBreak class given a valid wordBreak prop", function () {
      var wordBreak = "normal";
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        wordBreak: wordBreak
      }));
      expect(wrapper.find("Typography").childAt(0).hasClass("word-break-".concat(wordBreak))).toEqual(true);
    });
    it("gives an error given an invalid wordBreak prop", function () {
      var wordBreak = "invalid";
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
        wordBreak: wordBreak
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
});