"use strict";

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _react = _interopRequireDefault(require("react"));

var _VerticalProgressBar = _interopRequireDefault(require("./VerticalProgressBar"));

var _VerticalProgressBarItem = _interopRequireDefault(require("./VerticalProgressBarItem"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("<VerticalProgressBar>", function () {
  it("renders without errors", function () {
    var error;

    try {
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_VerticalProgressBar["default"], null));
    } catch (theError) {
      error = theError;
    }

    expect(error).toEqual(undefined);
  });
  it("renders correct snapshot", function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_VerticalProgressBar["default"], null));
    expect((0, _enzymeToJson["default"])(wrapper)).toMatchSnapshot();
  });
  describe("children prop", function () {
    it("renders given children", function () {
      var child = /*#__PURE__*/_react["default"].createElement("span", null, "this is a child");

      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_VerticalProgressBar["default"], null, child));
      expect(wrapper.text()).toContain("this is a child");
    });
    it("passes bar = false to last child", function () {
      var children = [/*#__PURE__*/_react["default"].createElement(_VerticalProgressBarItem["default"], {
        key: "1"
      }), /*#__PURE__*/_react["default"].createElement(_VerticalProgressBarItem["default"], {
        key: "2"
      })];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_VerticalProgressBar["default"], null, children));
      expect(wrapper.find("VerticalProgressBarItem").at(1).props().bar).toBe(false);
    });
    it("does not pass bar to non-last child", function () {
      var children = [/*#__PURE__*/_react["default"].createElement(_VerticalProgressBarItem["default"], {
        key: "1"
      }), /*#__PURE__*/_react["default"].createElement(_VerticalProgressBarItem["default"], {
        key: "2"
      })];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_VerticalProgressBar["default"], null, children));
      expect(wrapper.find("VerticalProgressBarItem").at(0).props().bar).toBe(true);
    });
  });
  describe("classes prop", function () {
    it("applies classes to the root node of VerticalProgressBar", function () {
      var classes = ["classOne"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_VerticalProgressBar["default"], {
        classes: classes
      }));
      expect(wrapper.find("VerticalProgressBar").childAt(0).props().classes).toContain(classes[0]);
    });
    it("appends higher order values to classes prop with withClasses decorator", function () {
      var classes = ["riipen", "riipen-verticalprogressbar"];
      var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_VerticalProgressBar["default"], null));
      expect(wrapper.find("VerticalProgressBar").props().classes.sort()).toEqual(classes.sort());
    });
    it("gives an error when classes are provided as one string", function () {
      var classes = "classOne classTwo";
      var errors = jest.spyOn(console, "error").mockImplementation();
      (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_VerticalProgressBar["default"], {
        classes: classes
      }));
      expect(errors).toHaveBeenCalled();
    });
  });
});