"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getDocument = getDocument;
exports.getContainer = getContainer;
exports.getClosestScrollableParent = getClosestScrollableParent;
exports["default"] = void 0;

/**
 * Get document element for owner container
 * @param {element} node - An element in the DOM
 * @return {string} The parent document element that contains the element
 */
function getDocument(node) {
  return node && node.ownerDocument || document;
}
/**
 * Get view elemtn for owner container
 * @param {element} node - An element in the DOM
 * @return {string} The parent view element that contains the element
 */


function getContainer(node) {
  var doc = getDocument(node);
  return doc.defaultView || window;
}
/**
 * Get closest parent that is scrollable
 * @param {element} node - An element in the DOM
 * @return {string} The closest scrollable parent view element that contains the element
 */


function getClosestScrollableParent(node) {
  if (!node || node === getDocument(node)) {
    return window;
  }

  var overflowY = window.getComputedStyle(node).overflowY;
  var isScrollable = overflowY !== "visible" && overflowY !== "hidden";

  if (isScrollable) {
    return node;
  }

  return getClosestScrollableParent(node.parentElement);
}

var _default = {
  getDocument: getDocument,
  getContainer: getContainer
};
exports["default"] = _default;